#!/usr/bin/env python
# -*- coding: utf-8 -*-

numbers = '0123456789'
symbols = "!@#$%^&*()[]"

chars_lower = dict()
chars_lower['en'] = 'abcdefghijklmnopqrstuvwxyz'
chars_lower['ru'] = u'абвгдеёжзийклмнопрстуфьцчшщъыьэюя'

consonants = dict()
consonants['en'] = 'bcdfghjklmnprstvwz'
consonants['ru'] = u'бвгджзклмнпрстфцчшщя'

vowels = dict()
vowels['en'] = 'aeiou'
vowels['ru'] = u'аеёиоуыэюя'




hex_pool = numbers + 'abcdef'
max_int = 9007199254740992
min_int = -max_int

extentions = (
    'txt',
    'jpg',
    'jpeg',
    'png',
    'js',
    'py',
    'java',
    'c',
    'cpp',
    'h',
    'md',
    'avi',
    'mp4',
    'ogg',
    'mp3',
    'so',
    'dll',
    'sh',
    'wav',
    'wmv',
    'css',
    'html',
    'xml',
    'cs',
)

# First names =====================================
first_names = dict()


first_names['en'] = {
    "m": ["James", "John", "Robert", "Michael", "William", "David", "Richard", "Joseph", "Charles", "Thomas", "Christopher", "Daniel", "Matthew", "George", "Donald", "Anthony", "Paul", "Mark", "Edward", "Steven", "Kenneth", "Andrew", "Brian", "Joshua", "Kevin", "Ronald", "Timothy", "Jason", "Jeffrey", "Frank", "Gary", "Ryan", "Nicholas", "Eric", "Stephen", "Jacob", "Larry", "Jonathan", "Scott", "Raymond", "Justin", "Brandon", "Gregory", "Samuel", "Benjamin", "Patrick", "Jack", "Henry", "Walter", "Dennis", "Jerry", "Alexander", "Peter", "Tyler", "Douglas", "Harold", "Aaron", "Jose", "Adam", "Arthur", "Zachary", "Carl", "Nathan", "Albert", "Kyle", "Lawrence", "Joe", "Willie", "Gerald", "Roger", "Keith", "Jeremy", "Terry", "Harry", "Ralph", "Sean", "Jesse", "Roy", "Louis", "Billy", "Austin", "Bruce", "Eugene", "Christian", "Bryan", "Wayne", "Russell", "Howard", "Fred", "Ethan", "Jordan", "Philip", "Alan", "Juan", "Randy", "Vincent", "Bobby", "Dylan", "Johnny", "Phillip", "Victor", "Clarence", "Ernest", "Martin", "Craig", "Stanley", "Shawn", "Travis", "Bradley", "Leonard", "Earl", "Gabriel", "Jimmy", "Francis", "Todd", "Noah", "Danny", "Dale", "Cody", "Carlos", "Allen", "Frederick", "Logan", "Curtis", "Alex", "Joel", "Luis", "Norman", "Marvin", "Glenn", "Tony", "Nathaniel", "Rodney", "Melvin", "Alfred", "Steve", "Cameron", "Chad", "Edwin", "Caleb", "Evan", "Antonio", "Lee", "Herbert", "Jeffery", "Isaac", "Derek", "Ricky", "Marcus", "Theodore", "Elijah", "Luke", "Jesus", "Eddie", "Troy", "Mike", "Dustin", "Ray", "Adrian", "Bernard", "Leroy", "Angel", "Randall", "Wesley", "Ian", "Jared", "Mason", "Hunter", "Calvin", "Oscar", "Clifford", "Jay", "Shane", "Ronnie", "Barry", "Lucas", "Corey", "Manuel", "Leo", "Tommy", "Warren", "Jackson", "Isaiah", "Connor", "Don", "Dean", "Jon", "Julian", "Miguel", "Bill", "Lloyd", "Charlie", "Mitchell", "Leon", "Jerome", "Darrell", "Jeremiah", "Alvin", "Brett", "Seth", "Floyd", "Jim", "Blake", "Micheal", "Gordon", "Trevor", "Lewis", "Erik", "Edgar", "Vernon", "Devin", "Gavin", "Jayden", "Chris", "Clyde", "Tom", "Derrick", "Mario", "Brent", "Marc", "Herman", "Chase", "Dominic", "Ricardo", "Franklin", "Maurice", "Max", "Aiden", "Owen", "Lester", "Gilbert", "Elmer", "Gene", "Francisco", "Glen", "Cory", "Garrett", "Clayton", "Sam", "Jorge", "Chester", "Alejandro", "Jeff", "Harvey", "Milton", "Cole", "Ivan", "Andre", "Duane", "Landon"],
    "f": ["Mary", "Emma", "Elizabeth", "Minnie", "Margaret", "Ida", "Alice", "Bertha", "Sarah", "Annie", "Clara", "Ella", "Florence", "Cora", "Martha", "Laura", "Nellie", "Grace", "Carrie", "Maude", "Mabel", "Bessie", "Jennie", "Gertrude", "Julia", "Hattie", "Edith", "Mattie", "Rose", "Catherine", "Lillian", "Ada", "Lillie", "Helen", "Jessie", "Louise", "Ethel", "Lula", "Myrtle", "Eva", "Frances", "Lena", "Lucy", "Edna", "Maggie", "Pearl", "Daisy", "Fannie", "Josephine", "Dora", "Rosa", "Katherine", "Agnes", "Marie", "Nora", "May", "Mamie", "Blanche", "Stella", "Ellen", "Nancy", "Effie", "Sallie", "Nettie", "Della", "Lizzie", "Flora", "Susie", "Maud", "Mae", "Etta", "Harriet", "Sadie", "Caroline", "Katie", "Lydia", "Elsie", "Kate", "Susan", "Mollie", "Alma", "Addie", "Georgia", "Eliza", "Lulu", "Nannie", "Lottie", "Amanda", "Belle", "Charlotte", "Rebecca", "Ruth", "Viola", "Olive", "Amelia", "Hannah", "Jane", "Virginia", "Emily", "Matilda", "Irene", "Kathryn", "Esther", "Willie", "Henrietta", "Ollie", "Amy", "Rachel", "Sara", "Estella", "Theresa", "Augusta", "Ora", "Pauline", "Josie", "Lola", "Sophia", "Leona", "Anne", "Mildred", "Ann", "Beulah", "Callie", "Lou", "Delia", "Eleanor", "Barbara", "Iva", "Louisa", "Maria", "Mayme", "Evelyn", "Estelle", "Nina", "Betty", "Marion", "Bettie", "Dorothy", "Luella", "Inez", "Lela", "Rosie", "Allie", "Millie", "Janie", "Cornelia", "Victoria", "Ruby", "Winifred", "Alta", "Celia", "Christine", "Beatrice", "Birdie", "Harriett", "Mable", "Myra", "Sophie", "Tillie", "Isabel", "Sylvia", "Carolyn", "Isabelle", "Leila", "Sally", "Ina", "Essie", "Bertie", "Nell", "Alberta", "Katharine", "Lora", "Rena", "Mina", "Rhoda", "Mathilda", "Abbie", "Eula", "Dollie", "Hettie", "Eunice", "Fanny", "Ola", "Lenora", "Adelaide", "Christina", "Lelia", "Nelle", "Sue", "Johanna", "Lilly", "Lucinda", "Minerva", "Lettie", "Roxie", "Cynthia", "Helena", "Hilda", "Hulda", "Bernice", "Genevieve", "Jean", "Cordelia", "Marian", "Francis", "Jeanette", "Adeline", "Gussie", "Leah", "Lois", "Lura", "Mittie", "Hallie", "Isabella", "Olga", "Phoebe", "Teresa", "Hester", "Lida", "Lina", "Winnie", "Claudia", "Marguerite", "Vera", "Cecelia", "Bess", "Emilie", "John", "Rosetta", "Verna", "Myrtie", "Cecilia", "Elva", "Olivia", "Ophelia", "Georgie", "Elnora", "Violet", "Adele", "Lily", "Linnie", "Loretta", "Madge", "Polly", "Virgie", "Eugenia", "Lucile", "Lucille", "Mabelle", "Rosalie"]
}
first_names['ru'] = {
    "m": ['Аарон', 'Август', 'Авдей', 'Аверьян', 'Агафон', 'Агей', 'Адам', 'Адриан', 'Аким', 'Аксён', 'Александр', 'Алексей', 'Али',  'Анатолий', 'Андрей', 'Анисий', 'Анисим', 'Антип', 'Антон', 'Ануфрий', 'Аркадий', 'Арон', 'Арсен', 'Арсений', 'Артём', 'Артемий', 'Артур', 'Архип', 'Афанасий', 'Бенедикт', 'Богдан', 'Борис', 'Борислав', 'Бронислав', 'Вадим', 'Валентин', 'Валерий', 'Валериан', 'Валерьян', 'Василий', 'Венедикт', 'Викентий', 'Виктор', 'Вилен', 'Вилор', 'Виталий', 'Владилен', 'Владимир', 'Владислав', 'Владлен', 'Влас', 'Всеволод', 'Вячеслав', 'Гавриил', 'Гаврила', 'Геннадий', 'Георгий', 'Герасим', 'Герман', 'Гертруд', 'Глеб', 'Гордей', 'Григорий', 'Гурий', 'Давид', 'Давыд', 'Даниил', 'Данила', 'Демид', 'Демьян', 'Денис', 'Димитрий', 'Диомид', 'Дмитрий', 'Дорофей', 'Евгений', 'Евдоким', 'Евсей', 'Евстафий', 'Евстигней', 'Егор', 'Елизар', 'Елисей', 'Емельян', 'Еремей', 'Ермил', 'Ермолай', 'Ерофей', 'Ефим', 'Ефимий', 'Ефрем', 'Жан', 'Жерар', 'Жорес', 'Захар', 'Захарий', 'Зиновий', 'Иван', 'Игнат', 'Игнатий', 'Игорь', 'Измаил', 'Изот', 'Иларион', 'Илья', 'Ильяс', 'Иосип', 'Иосиф', 'Ипполит', 'Исаак', 'Исак', 'Исидор', 'Искандер', 'Казимир', 'Калина', 'Каллиник', 'Каллистрат', 'Капитон', 'Карп', 'Касьян', 'Кирей', 'Кирила', 'Кирилл', 'Клементий', 'Клим', 'Климент', 'Климентий', 'Кондрат', 'Кондратий', 'Конон', 'Константин', 'Корней', 'Корнелий', 'Ксенофонт', 'Кузьма', 'Куприян', 'Лаврентий', 'Лазарь', 'Ларион', 'Лев', 'Левон', 'Леонид', 'Леон', 'Леонтий', 'Лука', 'Лукьян', 'Людвиг', 'Макар', 'Максим', 'Марат', 'Марк', 'Маркел', 'Мартин', 'Мартын', 'Матвей', 'Мефодий', 'Милослав', 'Мина', 'Минай', 'Мирон', 'Митрофан', 'Михаил', 'Михей', 'Модест', 'Моисей', 'Мокей', 'Мстислав', 'Назар', 'Наркис', 'Нарцис', 'Наум', 'Нестер', 'Нестор', 'Нефёд', 'Никандр', 'Никанор', 'Никита', 'Никифор', 'Никодим', 'Николай', 'Никон', 'Нил', 'Нильс', 'Олег', 'Онисим', 'Онуфрий', 'Орест', 'Осип', 'Остап', 'Отто', 'Павел', 'Панкрат', 'Панкратий', 'Пантелей', 'Пантелеймон', 'Парфён', 'Парфений', 'Пётр', 'Пимен', 'Платон', 'Полиграф', 'Поликарп', 'Порфир', 'Порфирий', 'Потап', 'Прокоп', 'Прокопий', 'Прокофий', 'Прохор', 'Роберт', 'Родион', 'Роман', 'Ростислав', 'Рубен', 'Руслан', 'Савастей', 'Савва', 'Савватий', 'Савелий', 'Самсон', 'Святослав', 'Северьян', 'Семён', 'Серафим', 'Сергей', 'Сергий', 'Сидор', 'Созон', 'Созонт', 'Спиридон', 'Станислав', 'Степан', 'Тарас', 'Теймураз', 'Терентий', 'Тимофей', 'Тимур', 'Тихон', 'Трифон', 'Трофим', 'Устин', 'Федот', 'Феликс', 'Фёдор', 'Федосей', 'Федосий', 'Феодосий', 'Феоктист', 'Феофан', 'Филат', 'Филимон', 'Филипп', 'Фока', 'Фома', 'Фрол', 'Харитон', 'Харлам', 'Харламп', 'Харлампий', 'Чеслав', 'Эдгар', 'Эдгард', 'Эдуард', 'Юлиан', 'Юлий', 'Юрий', 'Яков', 'Ярослав'],
    "f": ['Августина', 'Авдотья', 'Авелина', 'Аврелия', 'Аврея', 'Аврора', 'Агафья', 'Агапа', 'Агапия', 'Агата', 'Агафья', 'Аглая', 'Агнесса', 'Агния', 'Аграфена', 'Агриппина', 'Ада', 'Аделаида', 'Аделина', 'Адель', 'Адина', 'Адолия', 'Адриана', 'Азалия', 'Азелла', 'Аида', 'Аксинья', 'Акулина', 'Алевтина', 'Александра', 'Александрина', 'Алексина', 'Алёна', 'Алеся', 'Алина', 'Алиса', 'Алла', 'Алоиза', 'Алфея', 'Альберта', 'Альбертина', 'Альбина', 'Альвина', 'Альфия', 'Амалия', 'Амата', 'Анастасия', 'Анатолия', 'Ангела', 'Ангелика', 'Ангелина', 'Анджела', 'Андрея', 'Андрона', 'Андроника', 'Анета', 'Анетта', 'Анжела', 'Анжелика', 'Анимаиса', 'Анисия', 'Анисья', 'Анна', 'Аннета', 'Аннетта', 'Антонида', 'Антонина', 'Антония', 'Анфима', 'Анфиса', 'Анфия', 'Аполлинария', 'Аполлония', 'Апраксия', 'Апрелия', 'Апфия', 'Аргентея', 'Ариадна', 'Арина', 'Ария', 'Аркадия', 'Арсения', 'Артемида', 'Артемия', 'Аста', 'Астра', 'Астрид', 'Ася', 'Афанасия', 'Афродита', 'Аэлита', 'Аэлла', 'Ая', 'Беата', 'Беатриса', 'Белла', 'Бенедикта', 'Берта', 'Бландина', 'Богдана', 'Божена', 'Валентина', 'Валерия', 'Ванда', 'Ванесса', 'Варвара', 'Васёна', 'Василида', 'Василина', 'Василиса', 'Василия', 'Васса', 'Вацлава', 'Велимира', 'Велислава', 'Венедикта', 'Венера', 'Венцеслава', 'Вера', 'Вероника', 'Верония', 'Веселина', 'Весмира', 'Вика', 'Викторина', 'Виктория', 'Вилена', 'Виленина', 'Вилора', 'Вильгельмина', 'Виола', 'Виолетта', 'Вита', 'Виталика', 'Виталина', 'Виталия', 'Влада', 'Владилена', 'Владимира', 'Владислава', 'Владлена', 'Власта', 'Воля', 'Всеслава', 'Гала', 'Галата', 'Галатея', 'Галея', 'Галиана', 'Галиба', 'Галиля', 'Галима', 'Галина', 'Галя', 'Геласия', 'Гения', 'Геннадия', 'Генриетта', 'Георгина', 'Гера', 'Германа', 'Гертруда', 'Глафира', 'Горислава', 'Градислава', 'Грета', 'Гретта', 'Дарья', 'Дебора', 'Деина', 'Декабрина', 'Денисия', 'Диана', 'Дигна', 'Дина', 'Динара', 'Динора', 'Динэра', 'Диодора', 'Дионина', 'Дия', 'Доброгнева', 'Добромила', 'Добромира', 'Доброслава', 'Доминика', 'Домника', 'Домнина', 'Донара', 'Доната', 'Дора', 'Дорофея', 'Ева', 'Евгения', 'Евдокия', 'Екатерина', 'Елена', 'Елизавета', 'Ефросинья', 'Жасмин', 'Жанна', 'Жозефина', 'Залина', 'Зара', 'Зарема', 'Зарина', 'Заря', 'Земфира', 'Зиглинда', 'Зигрида', 'Зина', 'Зинаида', 'Зиновия', 'Злата', 'Зоя', 'Ива', 'Иванна', 'Ида', 'Идея', 'Иветта', 'Ивонна', 'Изабелла', 'Изида', 'Изольда', 'Илона', 'Инга', 'Инесса', 'Инна', 'Ира', 'Ирена', 'Ирина', 'Камилла', 'Карина', 'Кира', 'Кириана', 'Клавдия', 'Клара', 'Констанция', 'Корнелия', 'Кристина', 'Ксанфиппа', 'Ксения', 'Купава', 'Лада', 'Лариса', 'Лаура', 'Ленина', 'Леокадия', 'Леокардия', 'Леонида', 'Леонина', 'Леония', 'Лиана', 'Ливия', 'Лидия', 'Лилиана', 'Лилия', 'Лина', 'Лира', 'Лия', 'Лолита', 'Лолия', 'Луиза', 'Лукерья', 'Луна', 'Любава', 'Любовь', 'Любомила', 'Людмила', 'Люцина', 'Люция', 'Мавра', 'Магдалина', 'Майя', 'Макрина', 'Максима', 'Малания', 'Мальвина', 'Маргарита', 'Мариам', 'Мариамна', 'Марианна', 'Мариетта', 'Марина', 'Мариэтта', 'Мария', 'Марка', 'Марксина', 'Марлена', 'Марта', 'Марфа', 'Марья', 'Матрёна', 'Матрона', 'Мая', 'Мелания', 'Милена', 'Милица', 'Милия', 'Милослава', 'Милютина', 'Мина', 'Минна', 'Минодора', 'Мира', 'Миропия', 'Мирослава', 'Мирра', 'Митродора', 'Михайлина', 'Михалина', 'Моника', 'Муза', 'Нада', 'Надежда', 'Наина', 'Нана', 'Наталия', 'Наталья', 'Нелли', 'Ника', 'Нина', 'Нинель', 'Нонна', 'Ноябрина', 'Оксана', 'Октябрина', 'Олеся', 'Оливия', 'Олимпиада', 'Олимпиодора', 'Ольга', 'Офелия', 'Павлина', 'Пелагея', 'Полина', 'Прасковья', 'Раиса', 'Регина', 'Рената', 'Римма', 'Рита', 'Роза', 'Розалия', 'Сабина', 'Светлана', 'Серафима', 'Сильвия', 'Соня', 'Софья', 'София', 'Станислава', 'Степанида', 'Сусанна', 'Таисия', 'Тамара', 'Татьяна', 'Тереза', 'Ульяна', 'Фаина', 'Федосья', 'Шарлотта', 'Эвелина', 'Элеонора', 'Элла', 'Эльвира', 'Эмилия', 'Эмма', 'Юлиана', 'Юлия', 'Юния', 'Юнона', 'Юрия', 'Юстина', 'Яна', 'Янина', 'Ярослава', 'Ясна']
}
# End First names =====================================


# Last names =====================================

last_names = dict()

last_names['en'] = {
  'm' : ['Smith', 'Johnson', 'Williams', 'Jones', 'Brown', 'Davis', 'Miller', 'Wilson', 'Moore', 'Taylor', 'Anderson', 'Thomas', 'Jackson', 'White', 'Harris', 'Martin', 'Thompson', 'Garcia', 'Martinez', 'Robinson', 'Clark', 'Rodriguez', 'Lewis', 'Lee', 'Walker', 'Hall', 'Allen', 'Young', 'Hernandez', 'King', 'Wright', 'Lopez', 'Hill', 'Scott', 'Green', 'Adams', 'Baker', 'Gonzalez', 'Nelson', 'Carter', 'Mitchell', 'Perez', 'Roberts', 'Turner', 'Phillips', 'Campbell', 'Parker', 'Evans', 'Edwards', 'Collins', 'Stewart', 'Sanchez', 'Morris', 'Rogers', 'Reed', 'Cook', 'Morgan', 'Bell', 'Murphy', 'Bailey', 'Rivera', 'Cooper', 'Richardson', 'Cox', 'Howard', 'Ward', 'Torres', 'Peterson', 'Gray', 'Ramirez', 'James', 'Watson', 'Brooks', 'Kelly', 'Sanders', 'Price', 'Bennett', 'Wood', 'Barnes', 'Ross', 'Henderson', 'Coleman', 'Jenkins', 'Perry', 'Powell', 'Long', 'Patterson', 'Hughes', 'Flores', 'Washington', 'Butler', 'Simmons', 'Foster', 'Gonzales', 'Bryant', 'Alexander', 'Russell', 'Griffin', 'Diaz', 'Hayes', 'Myers', 'Ford', 'Hamilton', 'Graham', 'Sullivan', 'Wallace', 'Woods', 'Cole', 'West', 'Jordan', 'Owens', 'Reynolds', 'Fisher', 'Ellis', 'Harrison', 'Gibson', 'McDonald', 'Cruz', 'Marshall', 'Ortiz', 'Gomez', 'Murray', 'Freeman', 'Wells', 'Webb', 'Simpson', 'Stevens', 'Tucker', 'Porter', 'Hunter', 'Hicks', 'Crawford', 'Henry', 'Boyd', 'Mason', 'Morales', 'Kennedy', 'Warren', 'Dixon', 'Ramos', 'Reyes', 'Burns', 'Gordon', 'Shaw', 'Holmes', 'Rice', 'Robertson', 'Hunt', 'Black', 'Daniels', 'Palmer', 'Mills', 'Nichols', 'Grant', 'Knight', 'Ferguson', 'Rose', 'Stone', 'Hawkins', 'Dunn', 'Perkins', 'Hudson', 'Spencer', 'Gardner', 'Stephens', 'Payne', 'Pierce', 'Berry', 'Matthews', 'Arnold', 'Wagner', 'Willis', 'Ray', 'Watkins', 'Olson', 'Carroll', 'Duncan', 'Snyder', 'Hart', 'Cunningham', 'Bradley', 'Lane', 'Andrews', 'Ruiz', 'Harper', 'Fox', 'Riley', 'Armstrong', 'Carpenter', 'Weaver', 'Greene', 'Lawrence', 'Elliott', 'Chavez', 'Sims', 'Austin', 'Peters', 'Kelley', 'Franklin', 'Lawson', 'Fields', 'Gutierrez', 'Ryan', 'Schmidt', 'Carr', 'Vasquez', 'Castillo', 'Wheeler', 'Chapman', 'Oliver', 'Montgomery', 'Richards', 'Williamson', 'Johnston', 'Banks', 'Meyer', 'Bishop', 'McCoy', 'Howell', 'Alvarez', 'Morrison', 'Hansen', 'Fernandez', 'Garza', 'Harvey', 'Little', 'Burton', 'Stanley', 'Nguyen', 'George', 'Jacobs', 'Reid', 'Kim', 'Fuller', 'Lynch', 'Dean', 'Gilbert', 'Garrett', 'Romero', 'Welch', 'Larson', 'Frazier', 'Burke', 'Hanson', 'Day', 'Mendoza', 'Moreno', 'Bowman', 'Medina', 'Fowler', 'Brewer', 'Hoffman', 'Carlson', 'Silva', 'Pearson', 'Holland', 'Douglas', 'Fleming', 'Jensen', 'Vargas', 'Byrd', 'Davidson', 'Hopkins', 'May', 'Terry', 'Herrera', 'Wade', 'Soto', 'Walters', 'Curtis', 'Neal', 'Caldwell', 'Lowe', 'Jennings', 'Barnett', 'Graves', 'Jimenez', 'Horton', 'Shelton', 'Barrett', 'Obrien', 'Castro', 'Sutton', 'Gregory', 'McKinney', 'Lucas', 'Miles', 'Craig', 'Rodriquez', 'Chambers', 'Holt', 'Lambert', 'Fletcher', 'Watts', 'Bates', 'Hale', 'Rhodes', 'Pena', 'Beck', 'Newman', 'Haynes', 'McDaniel', 'Mendez', 'Bush', 'Vaughn', 'Parks', 'Dawson', 'Santiago', 'Norris', 'Hardy', 'Love', 'Steele', 'Curry', 'Powers', 'Schultz', 'Barker', 'Guzman', 'Page', 'Munoz', 'Ball', 'Keller', 'Chandler', 'Weber', 'Leonard', 'Walsh', 'Lyons', 'Ramsey', 'Wolfe', 'Schneider', 'Mullins', 'Benson', 'Sharp', 'Bowen', 'Daniel', 'Barber', 'Cummings', 'Hines', 'Baldwin', 'Griffith', 'Valdez', 'Hubbard', 'Salazar', 'Reeves', 'Warner', 'Stevenson', 'Burgess', 'Santos', 'Tate', 'Cross', 'Garner', 'Mann', 'Mack', 'Moss', 'Thornton', 'Dennis', 'McGee', 'Farmer', 'Delgado', 'Aguilar', 'Vega', 'Glover', 'Manning', 'Cohen', 'Harmon', 'Rodgers', 'Robbins', 'Newton', 'Todd', 'Blair', 'Higgins', 'Ingram', 'Reese', 'Cannon', 'Strickland', 'Townsend', 'Potter', 'Goodwin', 'Walton', 'Rowe', 'Hampton', 'Ortega', 'Patton', 'Swanson', 'Joseph', 'Francis', 'Goodman', 'Maldonado', 'Yates', 'Becker', 'Erickson', 'Hodges', 'Rios', 'Conner', 'Adkins', 'Webster', 'Norman', 'Malone', 'Hammond', 'Flowers', 'Cobb', 'Moody', 'Quinn', 'Blake', 'Maxwell', 'Pope', 'Floyd', 'Osborne', 'Paul', 'McCarthy', 'Guerrero', 'Lindsey', 'Estrada', 'Sandoval', 'Gibbs', 'Tyler', 'Gross', 'Fitzgerald', 'Stokes', 'Doyle', 'Sherman', 'Saunders', 'Wise', 'Colon', 'Gill', 'Alvarado', 'Greer', 'Padilla', 'Simon', 'Waters', 'Nunez', 'Ballard', 'Schwartz', 'McBride', 'Houston', 'Christensen', 'Klein', 'Pratt', 'Briggs', 'Parsons', 'McLaughlin', 'Zimmerman', 'French', 'Buchanan', 'Moran', 'Copeland', 'Roy', 'Pittman', 'Brady', 'McCormick', 'Holloway', 'Brock', 'Poole', 'Frank', 'Logan', 'Owen', 'Bass', 'Marsh', 'Drake', 'Wong', 'Jefferson', 'Park', 'Morton', 'Abbott', 'Sparks', 'Patrick', 'Norton', 'Huff', 'Clayton', 'Massey', 'Lloyd', 'Figueroa', 'Carson', 'Bowers', 'Roberson', 'Barton', 'Tran', 'Lamb', 'Harrington', 'Casey', 'Boone', 'Cortez', 'Clarke', 'Mathis', 'Singleton', 'Wilkins', 'Cain', 'Bryan', 'Underwood', 'Hogan', 'McKenzie', 'Collier', 'Luna', 'Phelps', 'McGuire', 'Allison', 'Bridges', 'Wilkerson', 'Nash', 'Summers', 'Atkins']
}
last_names['en']['f'] = last_names['en']['m']

last_names['ru'] = {
    'm': ['Абакумов', 'Абалышев', 'Абарников', 'Абдулов', 'Абрамов', 'Абрамович', 'Авандеев', 'Авдеев', 'Авдонин', 'Аверин', 'Аверьянов', 'Авилов', 'Автухов', 'Агапов', 'Агафонов', 'Агейкин', 'Аглиуллин', 'Адаксин', 'Ажикелямов', 'Ажищенков', 'Азаров', 'Аксаков', 'Акинфеев', 'Аксёнов', 'Аксенчук', 'Акулов', 'Алеев', 'Александров', 'Алексеев', 'Аленин', 'Алёхин', 'Алиев', 'Алистратов', 'Аллилуев', 'Алогрин', 'Амалиев', 'Амелин', 'Аминев', 'Ананьев', 'Анасенко', 'Андреев', 'Андреюшкин', 'Андроников', 'Андропов', 'Андрюхин', 'Аниканов', 'Аникин', 'Анисимов', 'Анишин', 'Анкудинов', 'Анников', 'Аносов', 'Анохин', 'Аношкин', 'Анреп', 'Антипин', 'Антипов', 'Антонов', 'Антонович', 'Апалков', 'Арданкин', 'Арефьев', 'Арзамасцев', 'Аристархов', 'Аристов', 'Арсеньев', 'Артамонов', 'Артемьев', 'Артёмов', 'Аршавин', 'Асланов', 'Аслаханов', 'Ассонов', 'Аспидов', 'Астанков', 'Астафьев', 'Астахов', 'Афанасьев', 'Афонин', 'Ахременко', 'Аюшиев', 'Бабанин', 'Бабатьев', 'Бабиков', 'Бабичев', 'Бабкин', 'Бабурин', 'Бабыкин', 'Багров', 'Баринов', 'Бажанов', 'Баженов', 'Базанов', 'Базаров', 'Базин', 'Бакрылов', 'Балабанов', 'Балакин', 'Балакирев', 'Баландин', 'Балахнов', 'Балашов', 'Балтабев', 'Бальсунов', 'Банин', 'Баранов', 'Барановский', 'Барболин', 'Баренцев', 'Баринов', 'Барков', 'Барндык', 'Барсуков', 'Барышев', 'Барышников', 'Батищев', 'Батрутдинов', 'Бебнев', 'Бебчук', 'Безбородов', 'Безродный', 'Безруков', 'Безукладников', 'Белевич', 'Белибердиев', 'Беликов', 'Белинский', 'Белитров', 'Белов', 'Белорусов', 'Белоглазов', 'Беломестин', 'Беломестнов', 'Беломестов', 'Беломестный', 'Беломестных', 'Белочкин', 'Белоусов', 'Беляков', 'Бендлин', 'Бенедиктов', 'Бережной', 'Березин', 'Берия', 'Бершов', 'Бескрёстнов', 'Беспалов', 'Бессонов', 'Бесфамильный', 'Бехтерев', 'Бирюков', 'Блаженов', 'Блантер', 'Блатов', 'Блинов', 'Блок', 'Блоков', 'Блохин', 'Блюм', 'Бобков', 'Бобр', 'Бобрик', 'Бобров', 'Боварин', 'Богатырёв', 'Богачёв', 'Богданов', 'Боголепов', 'Боголюбов', 'Богомазов', 'Богомолов', 'Богров', 'Богун', 'Бодров', 'Бойдало', 'Бойков', 'Бойцов', 'Бок', 'Бокарёв', 'Болдаев', 'Болдырев', 'Болотников', 'Болтоногов', 'Большаков', 'Большов', 'Бондарев', 'Бондарчук', 'Бореев', 'Борзилов', 'Борисюк', 'Бородин', 'Бортник', 'Борцов', 'Бочаров', 'Бояров', 'Брагин', 'Брантов', 'Брежнев', 'Брусилов', 'Бугаев', 'Бугайчук', 'Бугаков', 'Бузинский', 'Будаев', 'Буданов', 'Будников', 'Будылин', 'Букавицкий', 'Букин', 'Букирь', 'Буклин', 'Буков', 'Булгаков', 'Булыгин', 'Бунин', 'Бурдуковский', 'Бурков', 'Бурмакин', 'Буров', 'Бурцов', 'Бурый', 'Буряков', 'Бутурович', 'Бутусов', 'Бутылин', 'Бухало', 'Быков', 'Былинкин', 'Бычков', 'Вавилов', 'Вагин', 'Вазов', 'Валевач', 'Ванзин', 'Варенников', 'Варушкин', 'Васильев', 'Васильевых', 'Васин', 'Васнев', 'Васнецов', 'Вахров', 'Вахрушев', 'Венедиктов', 'Веденеев', 'Веденин', 'Ведерников', 'Вергунов', 'Верещагин', 'Вершинин', 'Веселов', 'Веселовский', 'Веточкин', 'Ветров', 'Викашев', 'Виноградов', 'Винокуров', 'Витаев', 'Витвинин', 'Вицин', 'Вихров', 'Водоватов', 'Bодовос', 'Водолеев', 'Водянов', 'Воликов', 'Волков', 'Володин', 'Волошин', 'Вольваков', 'Воробьёв', 'Воронин', 'Воронов', 'Воронков', 'Воронцов', 'Воскобойников', 'Вотяков', 'Вырыпаев', 'Вьялицын', 'Галерекин', 'Гавриков', 'Гаврилов', 'Гавриленков', 'Гагарин', 'Гаголин', 'Галдин', 'Галиаскаров', 'Галкин', 'Галыгин', 'Гаранин', 'Гарин', 'Гарифуллин', 'Гачев', 'Генкин', 'Герасимов', 'Гибазов', 'Гилёв', 'Глаголев', 'Глазков', 'Глебов', 'Глинин', 'Глоба', 'Глухов', 'Голов', 'Головаха', 'Голованов', 'Головин', 'Головкин', 'Голодяев', 'Голубев', 'Голубкин', 'Голубов', 'Голубцов', 'Голумбовский', 'Гончаров', 'горая', 'Горбачёв', 'Горбунков', 'Горбунов', 'Горев', 'Горелов', 'Горемыкин', 'Горохин', 'Горохов', 'Горностаев', 'Горшков', 'Горюнов', 'Грачёв', 'Графов', 'Гранкин', 'Гребенщиков', 'греков', 'Грешнев', 'Грибанов', 'Грибков', 'Грибов', 'Грибоедов', 'Григорьев', 'Гринин', 'Гришин', 'Громов', 'Груздев', 'Грузинский', 'Грушанин', 'Грязнов', 'Губанов', 'Гулин', 'Гунин', 'Гурковский', 'Гурьев', 'Гурьянов', 'Гусаров', 'Гусев', 'Гусин', 'Гусляков', 'Гуськов', 'Гущин', 'Даньшов', 'Дацишин', 'Дорофеев', 'Давыдкин', 'Давыдов', 'Данильцин', 'Двойнев', 'Дворников', 'Дедов', 'Деменок', 'Дементьев', 'Демидов', 'Деникин', 'Денисов', 'Дёгтин', 'Дегтярев', 'Дежнёв', 'Делов', 'Дементьев', 'Дёмин', 'Державин', 'Дернов', 'Десятков', 'Дмитриев', 'Добролюбов', 'Добронравов', 'Добрынин', 'Долгоруков', 'Должиков', 'Домашев', 'Домнин', 'Дорохин', 'Дорохов', 'Достовалов', 'Драгомиров', 'Драгунов', 'Дресвянин', 'Drotenkov', 'Дрёмов', 'Друганин', 'Другов', 'Дрягин', 'Дубинин', 'Дубинкин', 'Дубов', 'Дуболазов', 'Дубровский', 'Дудин', 'Дудко', 'Дудник', 'Дульцев', 'Думановский', 'Дунаевский', 'Дураничев', 'Дуров', 'Дурченко', 'Дырбов', 'Дыховичный', 'Дюженков', 'Дятлов', 'Евдокимов', 'Евсеев', 'Евстигнеев', 'Евтушенков', 'Егоров', 'Едемский', 'Ежов', 'Елагин', 'Елешев', 'Елизаров', 'Елисеев', 'Ельцин', 'Ельцов', 'Ельчуков', 'Емелин', 'Емельянов', 'Енин', 'Енотин', 'Енотов', 'Ерёмин', 'Ерзов', 'Еркулаев', 'Ермаков', 'Ермилов', 'Ермолаев', 'Ермолoв', 'Ермушин', 'Еромеев', 'Ерофеев', 'Ерохин', 'Ерхов', 'Ершов', 'Есаулов', 'Есиков', 'Есипов', 'Ефимов', 'Ефремов', 'Ешевский', 'Ёжиков', 'Ёжин', 'Ёжов', 'Ёлкин', 'Ёлков', 'Жабин', 'Жарков', 'Жарыхин', 'Жвиков', 'Жданов', 'Жеглов', 'Железкин', 'Железнов', 'Жердев', 'Жернаков', 'Жестакова', 'Жжёнов', 'Живенков', 'Жиглов', 'Жигунов', 'Жидков', 'Жикин', 'Жилин', 'Жилов', 'Жиренков', 'Жиров', 'Жолдин', 'Жуков', 'Жутов', 'Журавлёв', 'Журов', 'Заболотный', 'Заврагин', 'Завражин', 'Завражнов', 'Завражный', 'Завразин', 'Завьялов', 'Задорнов', 'Задорожный', 'Зайцев', 'Закревский', 'Закрятин', 'Запорожец', 'Заславский', 'Захаров', 'Захарьин', 'Захарченко', 'Зарубин', 'Звягин', 'Зефиров', 'Зёмин', 'Зимин', 'Злобин', 'Золин', 'Золотов', 'Зонов', 'Зорин', 'Зотов', 'Зубарев', 'Зубков', 'Зубов', 'Зуев', 'Зуйков', 'Зимняков', 'Зинченко', 'Зыкин', 'Зыков', 'Зырянов', 'Зюганов', 'Зверев', 'Ибрагимов', 'Ивазов', 'Ивакин', 'Иванков', 'Иванов', 'Ивашин', 'Ивашов', 'Ивкин', 'Ивченко', 'Иволгин', 'Игнаткович', 'Игнатьев', 'Игошин', 'Игумнов', 'Ижутин', 'Измайлов', 'Изюмов', 'Иканов', 'Икашев', 'Ильин', 'Илькун', 'Ильюшин', 'Ильясов', 'Илюхин', 'Илюшин', 'Илюшкин', 'Иноземцев', 'Иньшов', 'Ипатьев', 'Исаев', 'Исмайлов', 'Истомин', 'Ишутин', 'Кабинов', 'Каблуков', 'Каверин', 'Кадников', 'Кадцын', 'Кадурин', 'Казаков', 'Казанцев', 'Казаньков', 'Казарезов', 'Калагин', 'Калашник', 'Калганов', 'Калинин', 'Калугин', 'Калягин', 'Каменских', 'Камкин', 'Канадин', 'Канадов', 'Канадцев', 'Каналин', 'Кандинский', 'Капица', 'Капралов', 'Каприянов', 'Капустин', 'Капустов', 'Капылюшный', 'Караваев', 'Карандашов', 'Карантиров', 'Караулин', 'Караулов', 'Карбаинов', 'Каргин', 'Карев', 'Каретников', 'Каржов', 'Кариев', 'Карнаухов', 'Карташёв', 'Карташов', 'Карчагин', 'Карявин', 'Касатый', 'Каширский', 'Касьяненко', 'Касьянов', 'Катаев', 'Катериночкин', 'Катин', 'Качусов', 'Кашарин', 'Каширин', 'Кашканов', 'Кашников', 'Кашуба', 'Кедров', 'Килессо', 'Киприянов', 'Кирдань', 'Киреев', 'Киригин', 'Кирилишен', 'Кириллов', 'Кирилловский', 'Кирилов', 'Кирсанов', 'Кирьянов', 'Кислухин', 'Клепаk', 'Клепахов', 'Клепин', 'Климов', 'Климушин', 'Климцов', 'Клоков', 'Князев', 'Ковалевский', 'Коваленко', 'Ковалёв', 'Ковров', 'Ковшевников', 'Ковшутин', 'Кожуров', 'Кожухов', 'Козаков', 'Козарь', 'Козлов', 'Козловский', 'Козырев', 'Койчев', 'Колесников', 'Колесов', 'Коллеров', 'Колобков', 'Коломников', 'Колонтаев', 'Колосов', 'Кольцов', 'Колупаев', 'Комаров', 'Комзин', 'Комиссаров', 'Комолов', 'Кондратьев', 'Кондуров', 'Кондюрин', 'Конев', 'Конников', 'Коновалов', 'Коньяков', 'Коняшев', 'Копейкин', 'Копсов', 'Копцев', 'Кораблёв', 'Кораблин', 'Коренев', 'Коренёв', 'Коржаков', 'Коржев', 'Корнев', 'Корнеев', 'Корнилов', 'Коровин', 'Королёв', 'Коротаев', 'Короткин', 'Коротков', 'Кортнев', 'Корчагин', 'Корявин', 'Корявов', 'Косарёв', 'Косков', 'Косма', 'Косомов', 'Косоруков', 'Костин', 'Костомаров', 'Косяк', 'Котов', 'Коченков', 'Кочерёжкин', 'Кошелев', 'Кошечкин', 'Кошкин', 'Кошков', 'Кравчук', 'Краев', 'Краевский', 'Краснов', 'Красноперов', 'Красоткин', 'Кривков', 'Кривов', 'Кривоухов', 'Крючков', 'Кропанин', 'Кругликов', 'Круглов', 'Крупин', 'Крупнов', 'Крутиков', 'Крутин', 'Крутов', 'Крутой', 'Кручинкин', 'Крылов', 'Крымов', 'Крысов', 'Крюков', 'Кубланов', 'Кубышкин', 'Куваев', 'Кудашов', 'Кудрин', 'Кудрявцев', 'Кудряшов', 'Кузнецов', 'Кузубов', 'Кузькин', 'Кузьмин', 'Кузьмич', 'Куимов', 'Куклачёв', 'Куклев', 'Куклин', 'Куклов', 'Кулагин', 'Кулаков', 'Кулибин', 'Кулик', 'Куликов', 'Купцов', 'Куракин', 'Курбатов', 'Курганов', 'Курдин', 'Курепин', 'Курицын', 'Курочкин', 'Курпатов', 'Курсалин', 'Курташкин', 'Курчин', 'Кустов', 'Кутепов', 'Кутиков', 'Кутузов', 'Кутяков', 'Лаврентьев', 'Лавров', 'Лагошин', 'Лагранский', 'Лагутов', 'Лазарев', 'Ланцов', 'Лапаев', 'Лапидус', 'Лапин', 'Лапотников', 'Лаптев', 'Лапунов', 'Лапухов', 'Ларин', 'Ларионов', 'Ласкутин', 'Лачинов', 'Лачков', 'Лебедев', 'Лебединский', 'Лебединцев', 'Левин', 'Левкин', 'Легкодимов', 'Ледовской', 'Лелух', 'Лель', 'Леонидов', 'Леонов', 'Лепёхин', 'Лермонтов', 'Лесков', 'Лесничий', 'Летов', 'Лешев', 'Лещёв', 'Лёвкин', 'Лидин', 'Лилов', 'Лимонов', 'Липин', 'Липов', 'Лисицын', 'Лисов', 'Листратов', 'Листунов', 'Лихачёв', 'Лобан', 'Лобанов', 'Лобачёв', 'Лобов', 'Ловзанский', 'Логинов', 'Логиновский', 'Локтев', 'Локтионов', 'Ломовцев', 'Ломоносов', 'Ломтев', 'Лопатин', 'Лосев', 'Лосевский', 'Лоскутников', 'Лоскутов', 'Лощилов', 'Лубашев', 'Лужков', 'Лукашенко', 'Лукин', 'Луков', 'Лукьяненко', 'Лукьянов', 'Луский', 'Лызлов', 'Лыткин', 'Львов', 'Любимов', 'Любимцев', 'Любов', 'Лютенков', 'Лютов', 'Лягушкин', 'Лягушов', 'Лядов', 'Лялюшкин', 'Лямин', 'Ляпин', 'Ляпунов', 'Лясин', 'Мадулин', 'Магер', 'Магомедов', 'Мажулин', 'Майсак', 'Макаров', 'Маклаков', 'Максимов', 'Максимушкин', 'Максудов', 'Малахов', 'Маликов', 'Малинин', 'Малинов', 'Малышев', 'Малыхин', 'Мальчиков', 'Малюгин', 'Мамин', 'Мамонов', 'Мамыкин', 'Манин', 'Манторов', 'Манякин', 'Марин', 'Маринин', 'Маринкин', 'Маринов', 'Маркин', 'Марков', 'Мартюшев', 'Марьин', 'Маслак', 'Маслов', 'Масмех', 'Масмехов', 'Матвеев', 'Махмудов', 'Машарин', 'Машир', 'Медведев', 'Медведков', 'Медников', 'Меледин', 'Мелехов', 'Меликов', 'Мельников', 'Меншиков', 'Менщиков', 'Меркулов', 'Меркушев', 'Месяц', 'Механтьев', 'Мещеряков', 'Мигунов', 'Михайловна', 'Мизенов', 'Милехин', 'Милорадов', 'Милюков', 'Милютин', 'Минаев', 'Минеев', 'Минин', 'Минкин', '[Минковски]', 'Мирнов', 'Миров', 'Миронов', 'Мирохин', 'Мисалов', 'мишин', 'Митин', 'Митькин/Миткин', 'Митрофанов', 'Михайлов', 'Михалев', 'Михалицин', 'Михалицын', 'Михеев', 'Мишнев', 'Мишутин', 'Можаев', 'Моисеев', 'Молчанов', 'Мордвинов', 'Моренов', 'Морозов', 'Морошкин', 'Моряков', 'Мосалев', 'Мосин', 'Москвин', 'Мосяков', 'Мохов', 'Муравьёв', 'Муратов', 'Мурогов', 'Муханов', 'Мухин', 'Мухов', 'Мухоморов', 'Мухортов', 'Мышелов', 'Мышкин', 'Мягков', 'Мясников', 'Мятлев', 'Мяукин', 'Набатов', 'Назаров', 'Нардин', 'Насонов', 'Науменко', 'Наумов', 'Нетребов', 'Невзоров', 'Неделяев', 'Нежданов', 'Некрестьянов', 'Немцев', 'Немцов', 'Ненашев', 'Непеин', 'Нестеров', 'Нечаев', 'Низамутдинов', 'Никитин', 'Никифоров', 'Никишин', 'Николаев', 'Никонов', 'Никулин', 'Некрасов', 'Новиков', 'Новичков', 'Новокшонов', 'Новосельцев', 'Ноздрёв', 'Ноздрин', 'Норин', 'Носачёв', 'Носков', 'Носов', 'Нуриев', 'Оболенский', 'Обнизов', 'Оборин', 'Образцов', 'Обухов', 'Овечкин', 'Огородников', 'Огурцов', 'Озеров', 'Оленев', 'Ольховский', 'Омельницкий', 'Онегин', 'Онипченко', 'Опокин', 'Опринчук', 'Орлов', 'Осборн', 'Осенных', 'Осин', 'Осинов', 'Осинцев', 'Осминин', 'Осокин', 'Осолодкин', 'Остальцев', 'Остапюк', 'Островерхов', 'Островский', 'Ошурков', 'Овечкин', 'Павленко', 'Павлов', 'Палюлин', 'Панарин', 'Панин', 'Панкин', 'Панков', 'Панкратов', 'Панфилов', 'Панькив', 'Папанов', 'Парамонов', 'Паршиков', 'Паршин', 'Пастернак', 'Пастух', 'Пасхин', 'Патрушев', 'Паулкин', 'Пахомов', 'Пашин', 'Пашков', 'Певцов', 'Певчих', 'Пелевин', 'Пелёвин', 'Пенкин', 'Первак', 'Перевалов', 'Переверзев', 'Перевёртов', 'Пересторонин', 'Пережогин', 'Перехваткин', 'Перминов', 'Пермяков', 'Перов', 'Перфильев', 'Пестов', 'Петров', 'Петрухин', 'Петухов', 'Печеников', 'Печкин', 'Пивоваров', 'Пименов', 'Пирогов', 'Пирожков', 'Питосин', 'Пичугин', 'Пичушкин', 'Пищальников', 'Плаксин', 'Платонов', 'Племянников', 'Погодин', 'Погодов', 'Погребнов', 'Пода', 'Подшивалов', 'Пожарский', 'Поздняков', 'Покровский', 'Полачеав', 'Поливанов', 'Поличев', 'Полищук', 'Половцев', 'Полотенцев', 'Полтанов', 'Полторак', 'Полунин', 'Полушин', 'Поляков', 'Помелов', 'Помельников', 'Пондяков', 'Поникаров', 'Пономарёв', 'Пончиков', 'Попов', 'Попырин', 'Портнов', 'Посохов', 'Пост', 'Потапов', 'Потёмкин', 'Потрепалов', 'Праздников', 'Преображенский', 'Прибылов', 'Привалов', 'Примаков', 'Приходько', 'Пронин', 'Проничев', 'Проскуркин', 'Протасов', 'Прохоров', 'Пудо́вкин', 'Пугачёв', 'Пугин', 'Пудин', 'Пульдов', 'Пузаков', 'Пузанов', 'Путилин', 'Путилов', 'Путин', 'Путинов', 'Путятин', 'Пушкарёв', 'Пушкин', 'Пушной', 'Пшеничников', 'Пыжалов', 'Пырьев', 'Пьяных', 'Пятосин', 'Рабинович', 'Рабренович', 'Разин', 'Разуваев', 'Райт', 'Рамазанов', 'Раскалов', 'Распопов', 'Распутин', 'Рассказов', 'Расторгуев', 'Рафиков', 'Ревягин', 'Ревякин', 'Ремизов', 'Репин', 'Ретюнских', 'Решетилов', 'Решетников', 'Резансов', 'Резников', 'Ржевский', 'Рогачёв', 'Рогов', 'Рогозин', 'Родзянко', 'Родин', 'Родченко', 'Рожков', 'Розанов', 'Рокоссовский', 'Розовский', 'Романов', 'Ростов', 'Ростовцев', 'Рубашкин', 'Ругов', 'Рудавин', 'Рудин', 'Рудов', 'Рудников', 'Румянцев', 'Рунов', 'Русаков', 'Русанов', 'Руских', 'Руснак', 'Русских', 'Ручкин', 'Рощин', 'Рыбаков', 'Рыбалкин', 'Рындин', 'Рыжанов', 'Рыжков', 'Рыжиков', 'Рыжов', 'Рыков', 'Рытин', 'Рыченков', 'Рюриков', 'Рябкин', 'Рябков', 'Рябов', 'Рябцев', 'Ряхин', 'Сабанцев', 'Сабитов', 'Савасин', 'Савватимов', 'Саввин', 'Савинков', 'Савенков', 'Саврасов', 'Сагадеев', 'Садовский', 'Садыков', 'Сазонов', 'Саитов', 'Сай', 'Сайтахметов', 'Салагин', 'Салко', 'Салтанов', 'Сальков', 'Сальников', 'Самарин', 'Camapnh', 'Самойлов', 'Самохин', 'Самсонов', 'Санников', 'Сапалёв', 'Сапогов', 'Сапожников', 'Сапрыкин', 'Сарнычев', 'Сафиюлин', 'Сафронов', 'Сахаров', 'Саян', 'Саянкин', 'Саянков', 'Саянов', 'Саянович', 'Саянский', 'Свалов', 'Северинов', 'Северов', 'Севостьянов', 'Седельников', 'Седов', 'Селезнёв', 'Селиванов', 'Селидов', 'Семериков', 'Семёнов', 'Семичаевский', 'Семянин', 'Сенотрусов', 'Сенькин', 'Сергеев', 'Серебров', 'Серебряков', 'Серёгин', 'Серов', 'Серпионов', 'Сеченов', 'Сёмин', 'Сиваков', 'Сигаев', 'Сигачёв', 'Сигалов', 'Сидоров', 'Сизов', 'Сизый', 'Силаев', 'Силиванов', 'Силин', 'Сильвестров', 'Симакин', 'Симонов', 'Ситников', 'Сиякаев', 'Сиялов', 'Сиян', 'Сиянгулов', 'Сиянин', 'Сияница', 'Сиянкин', 'Сиянко', 'Сиянков', 'Сиянковский', 'Сиянов', 'Сиянович', 'Сияносов', 'Сиянский', 'Сиянских', 'Сиянцев', 'Сиянчук', 'Сиясинов', 'Скворцов', 'Скрябин', 'Скоробогатов', 'Скороходов', 'Скуратов', 'Славский', 'Слепынин', 'Слобожанин', 'Случевский', 'Смагин', 'Смирнитский', 'Смирнов', 'Сметанин', 'Смехов', 'Смешной', 'Смолин', 'Смолянинов', 'Смотров', 'Снаткин', 'Снегирёв', 'Снетков', 'Собаков', 'Собачкин', 'Соболев', 'Соболевский', 'Собчак', 'Соколов', 'Солдатов', 'Соловьёв', 'Солодников', 'Солодских', 'Соломахин', 'Соломин', 'Соломонов', 'Сомов', 'Сонин', 'Сопов', 'Сорокин', 'Сочинский', 'Спанов', 'Справцев', 'Сталин', 'Стариков', 'Старцев', 'Староверов', 'Староволков', 'Стародубов', 'Стародубцев', 'Статник', 'Стеблев', 'Стегнов', 'Степанов', 'Степанков', 'Степашин', 'Степнов', 'Стеженский', 'Стрекалов', 'Стрелков', 'Стрельников', 'Стрельцов', 'Строганов', 'Субботин', 'Суботин', 'Суворин', 'Суворкин', 'Суворов', 'Судленков', 'Сунгатулин', 'Сукачёв', 'Сукин', 'Султанов', 'Супрунов', 'Суриков', 'Сурков', 'Сурнин', 'Сусоев', 'Сусляков', 'Суснин', 'Сутулин', 'Суханов', 'Сухарников', 'Сухих', 'Сухоруков', 'Сучков', 'Счастливцев', 'Сысоев', 'Сытников', 'Сычёв', 'Сычкин', 'Сьянов', 'Сюкосев', 'Табаков', 'Табернакулов', 'Таланов', 'Талалихин', 'Тамаркин', 'Тамахин', 'Танков', 'Тарасов', 'Тарновецкий', 'Татаринов', 'Татаринцев', 'Татаров', 'Татауров', 'Таттар', 'Таушев', 'Твардовский', 'Телицын', 'Тёмкин', 'Теплов', 'Теребов', 'Терехов', 'Терещенко', 'Терёшин', 'Тетерев', 'Тимофеев', 'Тимошенко', 'Тимошкин', 'Типалов', 'Титов', 'Тихвинский', 'Тихомиров', 'Тихоненко', 'Тихонов', 'Тихоход', 'Ткачёв', 'Ткаченко', 'Токарев', 'Токмаков', 'Толбанов', 'Толкачёв', 'Толмачёв', 'Толоконский', 'Толстобров', 'Толстокожев', 'Толстой', 'Топоров', 'Топорков', 'Торопов', 'Торчинович', 'Травкин', 'Травников', 'Трактирников', 'Трапезников', 'Тредиаковский', 'Третьяков', 'Трифонов', 'Трофимов', 'Трусов', 'Трутнев', 'Труфанов', 'Трухин', 'Трындин', 'Тупицын', 'Туполев', 'Турбин', 'Тургенев', 'Тумасов', 'Туров', 'Турфанов', 'Тычкин', 'Тюшняков', 'Тянников', 'Уашингтон', 'Убыш', 'Убейсобакин', 'Уваров', 'Углов', 'Углицкий', 'Угличинин', 'Уголев', 'Угольников', 'Удом', 'Уицкий', 'Уланов', 'Уладимов', 'Улицкий', 'Ульянин', 'Ульянов', 'Ульяшин', 'Умаметев', 'Уманов', 'Умский', 'Унгерн', 'Унковский', 'Унтилов', 'Ураков', 'Уралец', 'Урбановский', 'Урусов', 'Усатов', 'Усачёв', 'Усенко', 'Усилов', 'Усов', 'Усоев', 'Успенский', 'Устимович', 'Устинов', 'Устюжанин', 'Уттеркло', 'Утёсов', 'Утюжин', 'Ухов', 'Ухтомский', 'Ушаков', 'Фаммус', 'Фамусов', 'Фанин', 'Федин', 'Федосов', 'Федотов', 'Федосеев', 'Федченков', 'Фехлачев', 'Фёдоров', 'Фёхлачев', 'Федулов', 'Фененко', 'Фетисов', 'Филатов', 'Филенков', 'Филимонов', 'Филипов', 'Филиппов', 'Фильченков', 'Флёров', 'Фокин', 'Фоменков', 'Фомин', 'Фомичёв', 'Фонвизин', 'Форопонов', 'Фирсов', 'Франко', 'Фролов', 'Францев', 'Фукин', 'Фурманов', 'Хабалов', 'Хабаров', 'Хабенский', 'Халипов', 'Халски', 'Халтурин', 'Хамидуллин', 'Ханилов', 'Ханипов', 'Ханцев', 'Харзин', 'Харитонов', 'Харламов', 'Хармац', 'Хаслик', 'Хвостовский', 'Хигир', 'Хлебников', 'Хлебов', 'Хлопонин', 'Хмельнов', 'Хохлачев', 'Ходяев', 'Холод', 'Холодов', 'Хомколов', 'Хорьков', 'Храмов', 'Хребтов', 'Хромов', 'Хрущёв', 'Худовеков', 'Худяков', 'Хуртин', 'Цаплин', 'Царёв', 'Царегородцев', 'Царицын', 'Царско', 'Цветков', 'Цветнов', 'Цветаев', 'Цвиленев', 'Цедлиц', 'Цейдлерин', 'Цейдлиц', 'Целиковский', 'Цельнер', 'Церетели', 'Цехановецкий', 'Циглер', 'Циммерман', 'Циолковский', 'Цирюльников', 'Цитников', 'Цицианов', 'Цуканов', 'Цулукидзе', 'Цыганов', 'Цызырев', 'Цыркунов', 'Цыринский', 'Чаадаев', 'Чадов', 'Чарков', 'Чазов', 'Чайка', 'Чайковский', 'Чалый', 'Чапаев', 'Чеботарёв', 'Чебыкин', 'Чежеков', 'Чекудаев', 'Чекмарёв', 'Челомеев', 'Челомей', 'Челомцев', 'Челпанов', 'Чемерис', 'Чендев', 'Чепурин', 'Черенчиков', 'Черепанов', 'Черкасов', 'Черкашин', 'Чернаков', 'Чернецкий', 'Черников', 'Чернобровин', 'Чернов', 'Черномырдин', 'Черных', 'Чернышёв', 'Чернявский', 'Чесноков', 'Чехов', 'Чиграков', 'Чижиков', 'Чилаев', 'Чиркаш', 'Чистяков', 'Чичиков', 'Чичканов', 'Чкалов', 'Чмыхов', 'Чубаров', 'Чугунов', 'Чудов', 'Чужинов', 'Чукчов', 'Чукреев', 'Чумаков', 'Чупалов', 'Чупахин', 'Чупов', 'Чупраков', 'Чуприн', 'Чупров', 'Чуркин', 'Чучанов', 'Чучумашев', 'Шабалин', 'Шабунин', 'Шагидзянов', 'Шакмаков', 'Шаломенцев', 'Шаляпин', 'Шаповалов', 'Шапошников', 'Шапиро', 'Шарапов', 'Шаров', 'Шаронов', 'Шаршин', 'Шастин', 'Шаталов', 'Шашлов', 'Шведов', 'Шверник', 'Шевелёк', 'Шелагин', 'Шелепов', 'Шеломов', 'Шеляпин', 'Шепкин', 'Шеповалов', 'Шереметьев', 'Шерков', 'Шерстов', 'Шибалов', 'Шигаев', 'Шигин', 'Шикалов', 'Шинский', 'Ширинов', 'Ширманов', 'Широков', 'Шихов', 'Шихранов', 'Шишканов', 'Шишкин', 'Шишко', 'Шишлов', 'Шишов', 'Шкуратов', 'Шкут', 'Шлыков', 'Шмагин', 'Шмаков', 'Шмелев', 'Шпак', 'Шпикалов', 'Шубин', 'Шубкин', 'Шувалов', 'Шуйский', 'Шукшин', 'Шулёв', 'Шуличенко', 'Шульга', 'Шульгин', 'Шульдешов', 'Шульц', 'Шурупин', 'Шурупов', 'Шурша', 'Шуршалин', 'Шурыгин', 'Шустелёв', 'Шушалев', 'Щавельский', 'Щавлев', 'Щегельский', 'Щеглов', 'Щеголев', 'Щеголихин', 'Щеголяев', 'Щедрин', 'Щедров', 'Щекочихин', 'Щепкин', 'Щербаков', 'Щербатых', 'Щербина', 'Щетинин', 'Щеткин', 'Щитт', 'Щукин', 'Щуров', 'Эйбоженко', 'Экель', 'Элефтеров', 'Элькин', 'Эльмпт', 'Эмануиль', 'Эмин', 'Эмский', 'Эмских', 'Энгалычев', 'Энгельгардт', 'Энговатов', 'Энтин', 'Энтский', 'Эпингер', 'Эрдели', 'Эристов', 'Эрнет', 'Эсце', 'Эсмонд', 'Эссен', 'Этуш', 'Эшман', 'Юбкин', 'Ювелев', 'Юганцев', 'Югов', 'Юдачёв', 'Юдашкин', 'Юдин', 'Юдицкий', 'Юматов', 'Юмашев', 'Юнге', 'Юневич', 'Юнкин', 'Юракин', 'Юрасов', 'Юренев', 'Юрков', 'Юрлов', 'Юрнаев', 'Юрьев', 'Юсупов', 'Ютилов', 'Юферев', 'Юханцев', 'Юхтриц', 'Юшаков', 'Юшков', 'Яблоков', 'Яблонев', 'Яблонский', 'Яговкин', 'Язов', 'Яйцев', 'Якименко', 'Якимов', 'Яковлев', 'Якубов', 'Якубович', 'Якунин', 'Якушев', 'Якушин', 'Ямских', 'Янаев', 'Янков', 'Янковский', 'Янукович', 'Ярмольник', 'Яромеев', 'Ярославский', 'Ярославцев', 'Ярцев', 'Ярцин', 'Ясенев', 'Яснеев', 'Яшин', 'Яшкин'],
    'f': ['Абакумова', 'Абалышева', 'Абарникова', 'Абдулова', 'Абрамова', 'Абрамович', 'Авандеева', 'Авдеева', 'Авдонина', 'Аверина', 'Аверьянова', 'Авилова', 'Автухова', 'Агапова', 'Агафонова', 'Агейкина', 'Аглиуллина', 'Адаксина', 'Ажикелямова', 'Ажищенкова', 'Азарова', 'Аксакова', 'Акинфеева', 'Аксёнова', 'Аксенчук', 'Акулова', 'Алеева', 'Александрова', 'Алексеева', 'Аленина', 'Алёхина', 'Алиева', 'Алистратова', 'Аллилуева', 'Алогрина', 'Амалиева', 'Амелина', 'Аминева', 'Ананьева', 'Анасенко', 'Андреева', 'Андреюшкина', 'Андроникова', 'Андропова', 'Андрюхина', 'Аниканова', 'Аникина', 'Анисимова', 'Анишина', 'Анкудинова', 'Анникова', 'Аносова', 'Анохина', 'Аношкина', 'Анреп', 'Антипина', 'Антипова', 'Антонова', 'Антонович', 'Апалкова', 'Арданкина', 'Арефьева', 'Арзамасцева', 'Аристархова', 'Аристова', 'Арсеньева', 'Артамонова', 'Артемьева', 'Артёмова', 'Аршавина', 'Асланова', 'Аслаханова', 'Ассонова', 'Аспидова', 'Астанкова', 'Астафьева', 'Астахова', 'Афанасьева', 'Афонина', 'Ахременко', 'Аюшиева', 'Бабанина', 'Бабатьева', 'Бабикова', 'Бабичева', 'Бабкина', 'Бабурина', 'Бабыкина', 'Багрова', 'Баринова', 'Бажанова', 'Баженова', 'Базанова', 'Базарова', 'Базина', 'Бакрылова', 'Балабанова', 'Балакина', 'Балакирева', 'Баландина', 'Балахнова', 'Балашова', 'Балтабева', 'Бальсунова', 'Банина', 'Баранова', 'Барановский', 'Барболина', 'Баренцева', 'Баринова', 'Баркова', 'Барндык', 'Барсукова', 'Барышева', 'Барышникова', 'Батищева', 'Батрутдинова', 'Бебнева', 'Бебчук', 'Безбородова', 'Безродных', 'Безрукова', 'Безукладникова', 'Белевич', 'Белибердиева', 'Беликова', 'Белинская', 'Белитрова', 'Белова', 'Белорусова', 'Белоглазова', 'Беломестина', 'Беломестнова', 'Беломестова', 'Беломестный', 'Беломестных', 'Белочкина', 'Белоусова', 'Белякова', 'Бендлина', 'Бенедиктова', 'Бережной', 'Березина', 'Берия', 'Бершова', 'Бескрёстнова', 'Беспалова', 'Бессонова', 'Бесфамильный', 'Бехтерева', 'Бирюкова', 'Блаженова', 'Блантер', 'Блатова', 'Блинова', 'Блок', 'Блокова', 'Блохина', 'Блюм', 'Бобкова', 'Бобр', 'Бобрик', 'Боброва', 'Боварина', 'Богатырёва', 'Богачёва', 'Богданова', 'Боголепова', 'Боголюбова', 'Богомазова', 'Богомолова', 'Богрова', 'Богуна', 'Бодрова', 'Бойдало', 'Бойкова', 'Бойцова', 'Бок', 'Бокарёва', 'Болдаева', 'Болдырева', 'Болотникова', 'Болтоногова', 'Большакова', 'Большова', 'Бондарева', 'Бондарчук', 'Бореева', 'Борзилова', 'Борисюк', 'Бородина', 'Бортник', 'Борцова', 'Бочарова', 'Боярова', 'Брагина', 'Брантова', 'Брежнева', 'Брусилова', 'Бугаева', 'Бугайчук', 'Бугакова', 'Бузинская', 'Будаева', 'Буданова', 'Будникова', 'Будылина', 'Букавицкая', 'Букина', 'Букирь', 'Буклина', 'Букова', 'Булгакова', 'Булыгина', 'Бунина', 'Бурдуковская', 'Буркова', 'Бурмакина', 'Бурова', 'Бурцова', 'Бурый', 'Бурякова', 'Бутурович', 'Бутусова', 'Бутылина', 'Бухало', 'Быкова', 'Былинкина', 'Бычкова', 'Вавилова', 'Вагина', 'Вазова', 'Валевач', 'Ванзина', 'Варенникова', 'Варушкина', 'Васильева', 'Васильевых', 'Васина', 'Васнева', 'Васнецова', 'Вахрова', 'Вахрушева', 'Венедиктова', 'Веденеева', 'Веденина', 'Ведерникова', 'Вергунова', 'Верещагина', 'Вершинина', 'Веселова', 'Веселовская', 'Веточкина', 'Ветрова', 'Викашева', 'Виноградова', 'Винокурова', 'Витаева', 'Витвинина', 'Вицина', 'Вихрова', 'Водоватова', 'Bодовос', 'Водолеева', 'Водянова', 'Воликова', 'Волкова', 'Володина', 'Волошина', 'Вольвакова', 'Воробьёва', 'Воронина', 'Воронова', 'Воронкова', 'Воронцова', 'Воскобойникова', 'Вотякова', 'Вырыпаева', 'Вьялицына', 'Галерекина', 'Гаврикова', 'Гаврилова', 'Гавриленкова', 'Гагарина', 'Гаголина', 'Галдина', 'Галиаскарова', 'Галкина', 'Галыгина', 'Гаранина', 'Гарина', 'Гарифуллина', 'Гачева', 'Генкина', 'Герасимова', 'Гибазова', 'Гилёва', 'Глаголева', 'Глазкова', 'Глебова', 'Глинина', 'Глоба', 'Глухова', 'Голова', 'Головаха', 'Голованова', 'Головина', 'Головкина', 'Голодяева', 'Голубева', 'Голубкина', 'Голубова', 'Голубцова', 'Голумбовская', 'Гончарова', 'горая', 'Горбачёва', 'Горбункова', 'Горбунова', 'Горева', 'Горелова', 'Горемыкина', 'Горохина', 'Горохова', 'Горностаева', 'Горшкова', 'Горюнова', 'Грачёва', 'Графова', 'Гранкина', 'Гребенщикова', 'грекова', 'Грешнева', 'Грибанова', 'Грибкова', 'Грибова', 'Грибоедова', 'Григорьева', 'Гринина', 'Гришина', 'Громова', 'Груздева', 'Грузинская', 'Грушанина', 'Грязнова', 'Губанова', 'Гулина', 'Гунина', 'Гурковская', 'Гурьева', 'Гурьянова', 'Гусарова', 'Гусева', 'Гусина', 'Гуслякова', 'Гуськова', 'Гущина', 'Даньшова', 'Дацишина', 'Дорофеева', 'Давыдкина', 'Давыдова', 'Данильцина', 'Двойнева', 'Дворникова', 'Дедова', 'Деменок', 'Дементьева', 'Демидова', 'Деникина', 'Денисова', 'Дёгтина', 'Дегтярева', 'Дежнёва', 'Делова', 'Дементьева', 'Дёмина', 'Державина', 'Дернова', 'Десяткова', 'Дмитриева', 'Добролюбова', 'Добронравова', 'Добрынина', 'Долгорукова', 'Должикова', 'Домашева', 'Домнина', 'Дорохина', 'Дорохова', 'Достовалова', 'Драгомирова', 'Драгунова', 'Дресвянина', 'Drotenkov', 'Дрёмова', 'Друганина', 'Другова', 'Дрягина', 'Дубинина', 'Дубинкина', 'Дубова', 'Дуболазова', 'Дубровская', 'Дудина', 'Дудко', 'Дудник', 'Дульцева', 'Думановская', 'Дунаевская', 'Дураничева', 'Дурова', 'Дурченко', 'Дырбова', 'Дыховичный', 'Дюженкова', 'Дятлова', 'Евдокимова', 'Евсеева', 'Евстигнеева', 'Евтушенкова', 'Егорова', 'Едемская', 'Ежова', 'Елагина', 'Елешева', 'Елизарова', 'Елисеева', 'Ельцина', 'Ельцова', 'Ельчукова', 'Емелина', 'Емельянова', 'Енина', 'Енотина', 'Енотова', 'Ерёмина', 'Ерзова', 'Еркулаева', 'Ермакова', 'Ермилова', 'Ермолаева', 'Ермолoва', 'Ермушина', 'Еромеева', 'Ерофеева', 'Ерохина', 'Ерхова', 'Ершова', 'Есаулова', 'Есикова', 'Есипова', 'Ефимова', 'Ефремова', 'Ешевская', 'Ёжикова', 'Ёжина', 'Ёжова', 'Ёлкина', 'Ёлкова', 'Жабина', 'Жаркова', 'Жарыхина', 'Жвикова', 'Жданова', 'Жеглова', 'Железкина', 'Железнова', 'Жердева', 'Жернакова', 'Жестакова', 'Жжёнова', 'Живенкова', 'Жиглова', 'Жигунова', 'Жидкова', 'Жикина', 'Жилина', 'Жилова', 'Жиренкова', 'Жирова', 'Жолдина', 'Жукова', 'Жутова', 'Журавлёва', 'Журова', 'Заболотный', 'Заврагина', 'Завражина', 'Завражнова', 'Завражный', 'Завразина', 'Завьялова', 'Задорнова', 'Задорожный', 'Зайцева', 'Закревская', 'Закрятина', 'Запорожецына', 'Заславская', 'Захарова', 'Захарьина', 'Захарченко', 'Зарубина', 'Звягина', 'Зефирова', 'Зёмина', 'Зимина', 'Злобина', 'Золина', 'Золотова', 'Зонова', 'Зорина', 'Зотова', 'Зубарева', 'Зубкова', 'Зубова', 'Зуева', 'Зуйкова', 'Зимнякова', 'Зинченко', 'Зыкина', 'Зыкова', 'Зырянова', 'Зюганова', 'Зверева', 'Ибрагимова', 'Ивазова', 'Ивакина', 'Иванкова', 'Иванова', 'Ивашина', 'Ивашова', 'Ивкина', 'Ивченко', 'Иволгина', 'Игнаткович', 'Игнатьева', 'Игошина', 'Игумнова', 'Ижутина', 'Измайлова', 'Изюмова', 'Иканова', 'Икашева', 'Ильина', 'Илькуна', 'Ильюшина', 'Ильясова', 'Илюхина', 'Илюшина', 'Илюшкина', 'Иноземцева', 'Иньшова', 'Ипатьева', 'Исаева', 'Исмайлова', 'Истомина', 'Ишутина', 'Кабинова', 'Каблукова', 'Каверина', 'Кадникова', 'Кадцына', 'Кадурина', 'Казакова', 'Казанцева', 'Казанькова', 'Казарезова', 'Калагина', 'Калашник', 'Калганова', 'Калинина', 'Калугина', 'Калягина', 'Каменских', 'Камкина', 'Канадина', 'Канадова', 'Канадцева', 'Каналина', 'Кандинская', 'Капица', 'Капралова', 'Каприянова', 'Капустина', 'Капустова', 'Капылюшный', 'Караваева', 'Карандашова', 'Карантирова', 'Караулина', 'Караулова', 'Карбаинова', 'Каргина', 'Карева', 'Каретникова', 'Каржова', 'Кариева', 'Карнаухова', 'Карташёва', 'Карташова', 'Карчагина', 'Карявина', 'Касатый', 'Каширская', 'Касьяненко', 'Касьянова', 'Катаева', 'Катериночкина', 'Катина', 'Качусова', 'Кашарина', 'Каширина', 'Кашканова', 'Кашникова', 'Кашуба', 'Кедрова', 'Килессо', 'Киприянова', 'Кирдань', 'Киреева', 'Киригина', 'Кирилишена', 'Кириллова', 'Кирилловская', 'Кирилова', 'Кирсанова', 'Кирьянова', 'Кислухина', 'Клепаk', 'Клепахова', 'Клепина', 'Климова', 'Климушина', 'Климцова', 'Клокова', 'Князева', 'Ковалевская', 'Коваленко', 'Ковалёва', 'Коврова', 'Ковшевникова', 'Ковшутина', 'Кожурова', 'Кожухова', 'Козакова', 'Козарь', 'Козлова', 'Козловская', 'Козырева', 'Койчева', 'Колесникова', 'Колесова', 'Коллерова', 'Колобкова', 'Коломникова', 'Колонтаева', 'Колосова', 'Кольцова', 'Колупаева', 'Комарова', 'Комзина', 'Комиссарова', 'Комолова', 'Кондратьева', 'Кондурова', 'Кондюрина', 'Конева', 'Конникова', 'Коновалова', 'Коньякова', 'Коняшева', 'Копейкина', 'Копсова', 'Копцева', 'Кораблёва', 'Кораблина', 'Коренева', 'Коренёва', 'Коржакова', 'Коржева', 'Корнева', 'Корнеева', 'Корнилова', 'Коровина', 'Королёва', 'Коротаева', 'Короткина', 'Короткова', 'Кортнева', 'Корчагина', 'Корявина', 'Корявова', 'Косарёва', 'Коскова', 'Косма', 'Косомова', 'Косорукова', 'Костина', 'Костомарова', 'Косяк', 'Котова', 'Коченкова', 'Кочерёжкина', 'Кошелева', 'Кошечкина', 'Кошкина', 'Кошкова', 'Кравчук', 'Краева', 'Краевская', 'Краснова', 'Красноперова', 'Красоткина', 'Кривкова', 'Кривова', 'Кривоухова', 'Крючкова', 'Кропанина', 'Кругликова', 'Круглова', 'Крупина', 'Крупнова', 'Крутикова', 'Крутина', 'Крутова', 'Крутой', 'Кручинкина', 'Крылова', 'Крымова', 'Крысова', 'Крюкова', 'Кубланова', 'Кубышкина', 'Куваева', 'Кудашова', 'Кудрина', 'Кудрявцева', 'Кудряшова', 'Кузнецова', 'Кузубова', 'Кузькина', 'Кузьмина', 'Кузьмич', 'Куимова', 'Куклачёва', 'Куклева', 'Куклина', 'Куклова', 'Кулагина', 'Кулакова', 'Кулибина', 'Кулик', 'Куликова', 'Купцова', 'Куракина', 'Курбатова', 'Курганова', 'Курдина', 'Курепина', 'Курицына', 'Курочкина', 'Курпатова', 'Курсалина', 'Курташкина', 'Курчина', 'Кустова', 'Кутепова', 'Кутикова', 'Кутузова', 'Кутякова', 'Лаврентьева', 'Лаврова', 'Лагошина', 'Лагранская', 'Лагутова', 'Лазарева', 'Ланцова', 'Лапаева', 'Лапидус', 'Лапина', 'Лапотникова', 'Лаптева', 'Лапунова', 'Лапухова', 'Ларина', 'Ларионова', 'Ласкутина', 'Лачинова', 'Лачкова', 'Лебедева', 'Лебединская', 'Лебединцева', 'Левина', 'Левкина', 'Легкодимова', 'Ледовской', 'Лелух', 'Лель', 'Леонидова', 'Леонова', 'Лепёхина', 'Лермонтова', 'Лескова', 'Лесничая', 'Летова', 'Лешева', 'Лещёва', 'Лёвкина', 'Лидина', 'Лилова', 'Лимонова', 'Липина', 'Липова', 'Лисицына', 'Лисова', 'Листратова', 'Листунова', 'Лихачёва', 'Лобана', 'Лобанова', 'Лобачёва', 'Лобова', 'Ловзанская', 'Логинова', 'Логиновская', 'Локтева', 'Локтионова', 'Ломовцева', 'Ломоносова', 'Ломтева', 'Лопатина', 'Лосева', 'Лосевская', 'Лоскутникова', 'Лоскутова', 'Лощилова', 'Лубашева', 'Лужкова', 'Лукашенко', 'Лукина', 'Лукова', 'Лукьяненко', 'Лукьянова', 'Луская', 'Лызлова', 'Лыткина', 'Львова', 'Любимова', 'Любимцева', 'Любова', 'Лютенкова', 'Лютова', 'Лягушкина', 'Лягушова', 'Лядова', 'Лялюшкина', 'Лямина', 'Ляпина', 'Ляпунова', 'Лясина', 'Мадулина', 'Магер', 'Магомедова', 'Мажулина', 'Майсак', 'Макарова', 'Маклакова', 'Максимова', 'Максимушкина', 'Максудова', 'Малахова', 'Маликова', 'Малинина', 'Малинова', 'Малышева', 'Малыхина', 'Мальчикова', 'Малюгина', 'Мамина', 'Мамонова', 'Мамыкина', 'Манина', 'Манторова', 'Манякина', 'Марина', 'Маринина', 'Маринкина', 'Маринова', 'Маркина', 'Маркова', 'Мартюшева', 'Марьина', 'Маслак', 'Маслова', 'Масмех', 'Масмехова', 'Матвеева', 'Махмудова', 'Машарина', 'Машир', 'Медведева', 'Медведкова', 'Медникова', 'Меледина', 'Мелехова', 'Меликова', 'Мельникова', 'Меншикова', 'Менщикова', 'Меркулова', 'Меркушева', 'Месяцына', 'Механтьева', 'Мещерякова', 'Мигунова', 'Михайловна', 'Мизенова', 'Милехина', 'Милорадова', 'Милюкова', 'Милютина', 'Минаева', 'Минеева', 'Минина', 'Минкина', '[Минковски]', 'Мирнова', 'Мирова', 'Миронова', 'Мирохина', 'Мисалова', 'мишина', 'Митина', 'Митькин/Миткина', 'Митрофанова', 'Михайлова', 'Михалева', 'Михалицина', 'Михалицына', 'Михеева', 'Мишнева', 'Мишутина', 'Можаева', 'Моисеева', 'Молчанова', 'Мордвинова', 'Моренова', 'Морозова', 'Морошкина', 'Морякова', 'Мосалева', 'Мосина', 'Москвина', 'Мосякова', 'Мохова', 'Муравьёва', 'Муратова', 'Мурогова', 'Муханова', 'Мухина', 'Мухова', 'Мухоморова', 'Мухортова', 'Мышелова', 'Мышкина', 'Мягкова', 'Мясникова', 'Мятлева', 'Мяукина', 'Набатова', 'Назарова', 'Нардина', 'Насонова', 'Науменко', 'Наумова', 'Нетребова', 'Невзорова', 'Неделяева', 'Нежданова', 'Некрестьянова', 'Немцева', 'Немцова', 'Ненашева', 'Непеина', 'Нестерова', 'Нечаева', 'Низамутдинова', 'Никитина', 'Никифорова', 'Никишина', 'Николаева', 'Никонова', 'Никулина', 'Некрасова', 'Новикова', 'Новичкова', 'Новокшонова', 'Новосельцева', 'Ноздрёва', 'Ноздрина', 'Норина', 'Носачёва', 'Носкова', 'Носова', 'Нуриева', 'Оболенская', 'Обнизова', 'Оборина', 'Образцова', 'Обухова', 'Овечкина', 'Огородникова', 'Огурцова', 'Озерова', 'Оленева', 'Ольховская', 'Омельницкая', 'Онегина', 'Онипченко', 'Опокина', 'Опринчук', 'Орлова', 'Осборна', 'Осенных', 'Осина', 'Осинова', 'Осинцева', 'Осминина', 'Осокина', 'Осолодкина', 'Остальцева', 'Остапюк', 'Островерхова', 'Островская', 'Ошуркова', 'Овечкина', 'Павленко', 'Павлова', 'Палюлина', 'Панарина', 'Панина', 'Панкина', 'Панкова', 'Панкратова', 'Панфилова', 'Панькива', 'Папанова', 'Парамонова', 'Паршикова', 'Паршина', 'Пастернак', 'Пастух', 'Пасхина', 'Патрушева', 'Паулкина', 'Пахомова', 'Пашина', 'Пашкова', 'Певцова', 'Певчих', 'Пелевина', 'Пелёвина', 'Пенкина', 'Первак', 'Перевалова', 'Переверзева', 'Перевёртова', 'Пересторонина', 'Пережогина', 'Перехваткина', 'Перминова', 'Пермякова', 'Перова', 'Перфильева', 'Пестова', 'Петрова', 'Петрухина', 'Петухова', 'Печеникова', 'Печкина', 'Пивоварова', 'Пименова', 'Пирогова', 'Пирожкова', 'Питосина', 'Пичугина', 'Пичушкина', 'Пищальникова', 'Плаксина', 'Платонова', 'Племянникова', 'Погодина', 'Погодова', 'Погребнова', 'Пода', 'Подшивалова', 'Пожарская', 'Позднякова', 'Покровская', 'Полачеава', 'Поливанова', 'Поличева', 'Полищук', 'Половцева', 'Полотенцева', 'Полтанова', 'Полторак', 'Полунина', 'Полушина', 'Полякова', 'Помелова', 'Помельникова', 'Пондякова', 'Поникарова', 'Пономарёва', 'Пончикова', 'Попова', 'Попырина', 'Портнова', 'Посохова', 'Пост', 'Потапова', 'Потёмкина', 'Потрепалова', 'Праздникова', 'Преображенская', 'Прибылова', 'Привалова', 'Примакова', 'Приходько', 'Пронина', 'Проничева', 'Проскуркина', 'Протасова', 'Прохорова', 'Пудо́вкина', 'Пугачёва', 'Пугина', 'Пудина', 'Пульдова', 'Пузакова', 'Пузанова', 'Путилина', 'Путилова', 'Путина', 'Путинова', 'Путятина', 'Пушкарёва', 'Пушкина', 'Пушной', 'Пшеничникова', 'Пыжалова', 'Пырьева', 'Пьяных', 'Пятосина', 'Рабинович', 'Рабренович', 'Разина', 'Разуваева', 'Райт', 'Рамазанова', 'Раскалова', 'Распопова', 'Распутина', 'Рассказова', 'Расторгуева', 'Рафикова', 'Ревягина', 'Ревякина', 'Ремизова', 'Репина', 'Ретюнских', 'Решетилова', 'Решетникова', 'Резансова', 'Резникова', 'Ржевская', 'Рогачёва', 'Рогова', 'Рогозина', 'Родзянко', 'Родина', 'Родченко', 'Рожкова', 'Розанова', 'Рокоссовская', 'Розовская', 'Романова', 'Ростова', 'Ростовцева', 'Рубашкина', 'Ругова', 'Рудавина', 'Рудина', 'Рудова', 'Рудникова', 'Румянцева', 'Рунова', 'Русакова', 'Русанова', 'Руских', 'Руснак', 'Русских', 'Ручкина', 'Рощина', 'Рыбакова', 'Рыбалкина', 'Рындина', 'Рыжанова', 'Рыжкова', 'Рыжикова', 'Рыжова', 'Рыкова', 'Рытина', 'Рыченкова', 'Рюрикова', 'Рябкина', 'Рябкова', 'Рябова', 'Рябцева', 'Ряхина', 'Сабанцева', 'Сабитова', 'Савасина', 'Савватимова', 'Саввина', 'Савинкова', 'Савенкова', 'Саврасова', 'Сагадеева', 'Садовская', 'Садыкова', 'Сазонова', 'Саитова', 'Сай', 'Сайтахметова', 'Салагина', 'Салко', 'Салтанова', 'Салькова', 'Сальникова', 'Самарина', 'Camapnh', 'Самойлова', 'Самохина', 'Самсонова', 'Санникова', 'Сапалёва', 'Сапогова', 'Сапожникова', 'Сапрыкина', 'Сарнычева', 'Сафиюлина', 'Сафронова', 'Сахарова', 'Саяна', 'Саянкина', 'Саянкова', 'Саянова', 'Саянович', 'Саянская', 'Свалова', 'Северинова', 'Северова', 'Севостьянова', 'Седельникова', 'Седова', 'Селезнёва', 'Селиванова', 'Селидова', 'Семерикова', 'Семёнова', 'Семичаевская', 'Семянина', 'Сенотрусова', 'Сенькина', 'Сергеева', 'Сереброва', 'Серебрякова', 'Серёгина', 'Серова', 'Серпионова', 'Сеченова', 'Сёмина', 'Сивакова', 'Сигаева', 'Сигачёва', 'Сигалова', 'Сидорова', 'Сизова', 'Сизый', 'Силаева', 'Силиванова', 'Силина', 'Сильвестрова', 'Симакина', 'Симонова', 'Ситникова', 'Сиякаева', 'Сиялова', 'Сияна', 'Сиянгулова', 'Сиянина', 'Сияница', 'Сиянкина', 'Сиянко', 'Сиянкова', 'Сиянковская', 'Сиянова', 'Сиянович', 'Сияносова', 'Сиянская', 'Сиянских', 'Сиянцева', 'Сиянчук', 'Сиясинова', 'Скворцова', 'Скрябина', 'Скоробогатова', 'Скороходова', 'Скуратова', 'Славская', 'Слепынина', 'Слобожанина', 'Случевская', 'Смагина', 'Смирнитская', 'Смирнова', 'Сметанина', 'Смехова', 'Смешной', 'Смолина', 'Смолянинова', 'Смотрова', 'Снаткина', 'Снегирёва', 'Снеткова', 'Собакова', 'Собачкина', 'Соболева', 'Соболевская', 'Собчак', 'Соколова', 'Солдатова', 'Соловьёва', 'Солодникова', 'Солодских', 'Соломахина', 'Соломина', 'Соломонова', 'Сомова', 'Сонина', 'Сопова', 'Сорокина', 'Сочинская', 'Спанова', 'Справцева', 'Сталина', 'Старикова', 'Старцева', 'Староверова', 'Староволкова', 'Стародубова', 'Стародубцева', 'Статник', 'Стеблева', 'Стегнова', 'Степанова', 'Степанкова', 'Степашина', 'Степнова', 'Стеженская', 'Стрекалова', 'Стрелкова', 'Стрельникова', 'Стрельцова', 'Строганова', 'Субботина', 'Суботина', 'Суворина', 'Суворкина', 'Суворова', 'Судленкова', 'Сунгатулина', 'Сукачёва', 'Сукина', 'Султанова', 'Супрунова', 'Сурикова', 'Суркова', 'Сурнина', 'Сусоева', 'Суслякова', 'Суснина', 'Сутулина', 'Суханова', 'Сухарникова', 'Сухих', 'Сухорукова', 'Сучкова', 'Счастливцева', 'Сысоева', 'Сытникова', 'Сычёва', 'Сычкина', 'Сьянова', 'Сюкосева', 'Табакова', 'Табернакулова', 'Таланова', 'Талалихина', 'Тамаркина', 'Тамахина', 'Танкова', 'Тарасова', 'Тарновецкая', 'Татаринова', 'Татаринцева', 'Татарова', 'Татаурова', 'Таттар', 'Таушева', 'Твардовская', 'Телицына', 'Тёмкина', 'Теплова', 'Теребова', 'Терехова', 'Терещенко', 'Терёшина', 'Тетерева', 'Тимофеева', 'Тимошенко', 'Тимошкина', 'Типалова', 'Титова', 'Тихвинская', 'Тихомирова', 'Тихоненко', 'Тихонова', 'Тихоход', 'Ткачёва', 'Ткаченко', 'Токарева', 'Токмакова', 'Толбанова', 'Толкачёва', 'Толмачёва', 'Толоконская', 'Толстоброва', 'Толстокожева', 'Толстой', 'Топорова', 'Топоркова', 'Торопова', 'Торчинович', 'Травкина', 'Травникова', 'Трактирникова', 'Трапезникова', 'Тредиаковская', 'Третьякова', 'Трифонова', 'Трофимова', 'Трусова', 'Трутнева', 'Труфанова', 'Трухина', 'Трындина', 'Тупицына', 'Туполева', 'Турбина', 'Тургенева', 'Тумасова', 'Турова', 'Турфанова', 'Тычкина', 'Тюшнякова', 'Тянникова', 'Уашингтона', 'Убыш', 'Убейсобакина', 'Уварова', 'Углова', 'Углицкая', 'Угличинина', 'Уголева', 'Угольникова', 'Удом', 'Уицкая', 'Уланова', 'Уладимова', 'Улицкая', 'Ульянина', 'Ульянова', 'Ульяшина', 'Умаметева', 'Уманова', 'Умская', 'Унгерна', 'Унковская', 'Унтилова', 'Уракова', 'Уралецына', 'Урбановская', 'Урусова', 'Усатова', 'Усачёва', 'Усенко', 'Усилова', 'Усова', 'Усоева', 'Успенская', 'Устимович', 'Устинова', 'Устюжанина', 'Уттеркло', 'Утёсова', 'Утюжина', 'Ухова', 'Ухтомская', 'Ушакова', 'Фаммус', 'Фамусова', 'Фанина', 'Федина', 'Федосова', 'Федотова', 'Федосеева', 'Федченкова', 'Фехлачева', 'Фёдорова', 'Фёхлачева', 'Федулова', 'Фененко', 'Фетисова', 'Филатова', 'Филенкова', 'Филимонова', 'Филипова', 'Филиппова', 'Фильченкова', 'Флёрова', 'Фокина', 'Фоменкова', 'Фомина', 'Фомичёва', 'Фонвизина', 'Форопонова', 'Фирсова', 'Франко', 'Фролова', 'Францева', 'Фукина', 'Фурманова', 'Хабалова', 'Хабарова', 'Хабенская', 'Халипова', 'Халски', 'Халтурина', 'Хамидуллина', 'Ханилова', 'Ханипова', 'Ханцева', 'Харзина', 'Харитонова', 'Харламова', 'Хармацына', 'Хаслик', 'Хвостовская', 'Хигир', 'Хлебникова', 'Хлебова', 'Хлопонина', 'Хмельнова', 'Хохлачева', 'Ходяева', 'Холод', 'Холодова', 'Хомколова', 'Хорькова', 'Храмова', 'Хребтова', 'Хромова', 'Хрущёва', 'Худовекова', 'Худякова', 'Хуртина', 'Цаплина', 'Царёва', 'Царегородцева', 'Царицына', 'Царско', 'Цветкова', 'Цветнова', 'Цветаева', 'Цвиленева', 'Цедлицына', 'Цейдлерина', 'Цейдлицына', 'Целиковская', 'Цельнер', 'Церетели', 'Цехановецкая', 'Циглер', 'Циммермана', 'Циолковская', 'Цирюльникова', 'Цитникова', 'Цицианова', 'Цуканова', 'Цулукидзе', 'Цыганова', 'Цызырева', 'Цыркунова', 'Цыринская', 'Чаадаева', 'Чадова', 'Чаркова', 'Чазова', 'Чайка', 'Чайковская', 'Чалый', 'Чапаева', 'Чеботарёва', 'Чебыкина', 'Чежекова', 'Чекудаева', 'Чекмарёва', 'Челомеева', 'Челомей', 'Челомцева', 'Челпанова', 'Чемерис', 'Чендева', 'Чепурина', 'Черенчикова', 'Черепанова', 'Черкасова', 'Черкашина', 'Чернакова', 'Чернецкая', 'Черникова', 'Чернобровина', 'Чернова', 'Черномырдина', 'Черных', 'Чернышёва', 'Чернявская', 'Чеснокова', 'Чехова', 'Чигракова', 'Чижикова', 'Чилаева', 'Чиркаш', 'Чистякова', 'Чичикова', 'Чичканова', 'Чкалова', 'Чмыхова', 'Чубарова', 'Чугунова', 'Чудова', 'Чужинова', 'Чукчова', 'Чукреева', 'Чумакова', 'Чупалова', 'Чупахина', 'Чупова', 'Чупракова', 'Чуприна', 'Чупрова', 'Чуркина', 'Чучанова', 'Чучумашева', 'Шабалина', 'Шабунина', 'Шагидзянова', 'Шакмакова', 'Шаломенцева', 'Шаляпина', 'Шаповалова', 'Шапошникова', 'Шапиро', 'Шарапова', 'Шарова', 'Шаронова', 'Шаршина', 'Шастина', 'Шаталова', 'Шашлова', 'Шведова', 'Шверник', 'Шевелёк', 'Шелагина', 'Шелепова', 'Шеломова', 'Шеляпина', 'Шепкина', 'Шеповалова', 'Шереметьева', 'Шеркова', 'Шерстова', 'Шибалова', 'Шигаева', 'Шигина', 'Шикалова', 'Шинская', 'Ширинова', 'Ширманова', 'Широкова', 'Шихова', 'Шихранова', 'Шишканова', 'Шишкина', 'Шишко', 'Шишлова', 'Шишова', 'Шкуратова', 'Шкут', 'Шлыкова', 'Шмагина', 'Шмакова', 'Шмелева', 'Шпак', 'Шпикалова', 'Шубина', 'Шубкина', 'Шувалова', 'Шуйская', 'Шукшина', 'Шулёва', 'Шуличенко', 'Шульга', 'Шульгина', 'Шульдешова', 'Шульцына', 'Шурупина', 'Шурупова', 'Шурша', 'Шуршалина', 'Шурыгина', 'Шустелёва', 'Шушалева', 'Щавельская', 'Щавлева', 'Щегельская', 'Щеглова', 'Щеголева', 'Щеголихина', 'Щеголяева', 'Щедрина', 'Щедрова', 'Щекочихина', 'Щепкина', 'Щербакова', 'Щербатых', 'Щербина', 'Щетинина', 'Щеткина', 'Щитт', 'Щукина', 'Щурова', 'Эйбоженко', 'Экель', 'Элефтерова', 'Элькина', 'Эльмпт', 'Эмануиль', 'Эмина', 'Эмская', 'Эмских', 'Энгалычева', 'Энгельгардт', 'Энговатова', 'Энтина', 'Энтская', 'Эпингер', 'Эрдели', 'Эристова', 'Эрнет', 'Эсце', 'Эсмонд', 'Эссена', 'Этуш', 'Эшмана', 'Юбкина', 'Ювелева', 'Юганцева', 'Югова', 'Юдачёва', 'Юдашкина', 'Юдина', 'Юдицкая', 'Юматова', 'Юмашева', 'Юнге', 'Юневич', 'Юнкина', 'Юракина', 'Юрасова', 'Юренева', 'Юркова', 'Юрлова', 'Юрнаева', 'Юрьева', 'Юсупова', 'Ютилова', 'Юферева', 'Юханцева', 'Юхтрицына', 'Юшакова', 'Юшкова', 'Яблокова', 'Яблонева', 'Яблонская', 'Яговкина', 'Язова', 'Яйцева', 'Якименко', 'Якимова', 'Яковлева', 'Якубова', 'Якубович', 'Якунина', 'Якушева', 'Якушина', 'Ямских', 'Янаева', 'Янкова', 'Янковская', 'Янукович', 'Ярмольник', 'Яромеева', 'Ярославская', 'Ярославцева', 'Ярцева', 'Ярцина', 'Ясенева', 'Яснеева', 'Яшина', 'Яшкина']
}


# End Last names =====================================


# Streets suffixes =====================================

streets_suffixes = dict()

streets_suffixes['en'] = [
   
            { 
                'name': 'Avenue', 
                'abbreviation': 'Ave'
            },
            { 
                'name': 'Boulevard', 
                'abbreviation': 'Blvd'
            },
            { 
                'name': 'Center', 
                'abbreviation': 'Ctr'
            },
            { 
                'name': 'Circle', 
                'abbreviation': 'Cir'
            },
            { 
                'name': 'Court', 
                'abbreviation': 'Ct'
            },
            { 
                'name': 'Drive', 
                'abbreviation': 'Dr'
            },
            { 
                'name': 'Extension', 
                'abbreviation': 'Ext'
            },
            { 
                'name': 'Glen', 
                'abbreviation': 'Gln'
            },
            { 
                'name': 'Grove', 
                'abbreviation': 'Grv'
            },
            { 
                'name': 'Heights', 
                'abbreviation': 'Hts'
            },
            { 
                'name': 'Highway', 
                'abbreviation': 'Hwy'
            },
            { 
                'name': 'Junction', 
                'abbreviation': 'Jct'
            },
            { 
                'name': 'Key', 
                'abbreviation': 'Key'
            },
            { 
                'name': 'Lane', 
                'abbreviation': 'Ln'
            },
            { 
                'name': 'Loop', 
                'abbreviation': 'Loop'
            },
            { 
                'name': 'Manor', 
                'abbreviation': 'Mnr'
            },
            { 
                'name': 'Mill', 
                'abbreviation': 'Mill'
            },
            { 
                'name': 'Park', 
                'abbreviation': 'Park'
            },
            { 
                'name': 'Parkway', 
                'abbreviation': 'Pkwy'
            },
            { 
                'name': 'Pass', 
                'abbreviation': 'Pass'
            },
            { 
                'name': 'Path', 
                'abbreviation': 'Path'
            },
            { 
                'name': 'Pike', 
                'abbreviation': 'Pike'
            },
            { 
                'name': 'Place', 
                'abbreviation': 'Pl'
            },
            { 
                'name': 'Plaza', 
                'abbreviation': 'Plz'
            },
            { 
                'name': 'Point', 
                'abbreviation': 'Pt'
            },
            { 
                'name': 'Ridge', 
                'abbreviation': 'Rdg'
            },
            { 
                'name': 'River', 
                'abbreviation': 'Riv'
            },
            { 
                'name': 'Road', 
                'abbreviation': 'Rd'
            },
            { 
                'name': 'Square', 
                'abbreviation': 'Sq'
            },
            { 
                'name': 'Street', 
                'abbreviation': 'St'
            },
            { 
                'name': 'Terrace', 
                'abbreviation': 'Ter'
            },
            { 
                'name': 'Trail', 
                'abbreviation': 'Trl'
            },
            { 
                'name': 'Turnpike', 
                'abbreviation': 'Tpke'
            },
            { 
                'name': 'View', 
                'abbreviation': 'Vw'
            },
            { 
                'name': 'Way', 
                'abbreviation': 'Way'
            }
]

# Abbreviations taken from here http://ruspostindex.ru/abr.html
streets_suffixes['ru'] = [
   
            { 
                'name': u'Проспект', 
                'abbreviation': u'пр-кт'
            },
            { 
                'name': u'Бульвар', 
                'abbreviation': u'б-р'
            },
            { 
                'name': u'Переулок', 
                'abbreviation': u'пер.'
            },
            { 
                'name': u'Проезд', 
                'abbreviation': u'пр.'
            },
            {
                'name': u'Улица',
                'abbreviation': u'ул.'
            }
]


# States USA
states = dict()

states['en'] = [
    {
       'name': 'Alabama',
       'abbreviation': 'AL'
    },
    {
       'name': 'Alaska',
       'abbreviation': 'AK'
    },
    {
       'name': 'American Samoa', 
       'abbreviation': 'AS'
    },
    {
       'name': 'Arizona', 
       'abbreviation': 'AZ'
    },
    {
       'name': 'Arkansas',
       'abbreviation': 'AR'
    },
    {
       'name': 'Armed Forces Europe',
       'abbreviation': 'AE'
    },
    {
       'name': 'Armed Forces Pacific',
       'abbreviation': 'AP'
    },
    {
        'name': 'Armed Forces the Americas', 
        'abbreviation': 'AA'
    },
    {
        'name': 'California', 
        'abbreviation': 'CA'
    },
    {
        'name': 'Colorado', 
        'abbreviation': 'CO'
    },
    {
      	'name': 'Connecticut', 
      	'abbreviation': 'CT'
    },
    {
     	'name': 'Delaware', 
     	'abbreviation': 'DE'
    },
    {
    	'name': 'District of Columbia', 
    	'abbreviation': 'DC'
   	},
    {
    	'name': 'Federated States of Micronesia', 
    	'abbreviation': 'FM'
   	},
    {
         'name': 'Florida', 
         'abbreviation': 'FL'
    },
    {
         'name': 'Georgia', 
         'abbreviation': 'GA'
    },
    {
         'name': 'Guam', 
         'abbreviation': 'GU'
    },
    {
         'name': 'Hawaii', 
         'abbreviation': 'HI'
    },
    {
         'name': 'Idaho', 
         'abbreviation': 'ID'
    },
    {
         'name': 'Illinois', 
         'abbreviation': 'IL'
    },
    {
         'name': 'Indiana', 
         'abbreviation': 'IN'
    },
    {
         'name': 'Iowa', 
         'abbreviation': 'IA'
    },
    {
         'name': 'Kansas', 
         'abbreviation': 'KS'
    },
    {
         'name': 'Kentucky', 
         'abbreviation': 'KY'
    },
    {
         'name': 'Louisiana', 
         'abbreviation': 'LA'
    },
    {
         'name': 'Maine', 
         'abbreviation': 'ME'
    },
    {
         'name': 'Marshall Islands', 
         'abbreviation': 'MH'
    },
    {
         'name': 'Maryland', 
         'abbreviation': 'MD'
    },
    {
         'name': 'Massachusetts', 
         'abbreviation': 'MA'
    },
    {
         'name': 'Michigan', 
         'abbreviation': 'MI'
    },
    {
         'name': 'Minnesota', 
         'abbreviation': 'MN'
    },
    {
         'name': 'Mississippi', 
         'abbreviation': 'MS'
    },
    {
         'name': 'Missouri', 
         'abbreviation': 'MO'
    },
    {
         'name': 'Montana', 
         'abbreviation': 'MT'
    },
    {
         'name': 'Nebraska', 
         'abbreviation': 'NE'
    },
    {
         'name': 'Nevada', 
         'abbreviation': 'NV'
    },
    {
         'name': 'New Hampshire', 
         'abbreviation': 'NH'
    },
    {
         'name': 'New Jersey', 
         'abbreviation': 'NJ'
    },
    {
         'name': 'New Mexico', 
         'abbreviation': 'NM'
    },
    {
         'name': 'New York', 
         'abbreviation': 'NY'
    },
    {
         'name': 'North Carolina', 
         'abbreviation': 'NC'
    },
    {
         'name': 'North Dakota', 
         'abbreviation': 'ND'
    },
    {
         'name': 'Northern Mariana Islands', 
         'abbreviation': 'MP'
    },
    {
         'name': 'Ohio', 
         'abbreviation': 'OH'
    },
    {
         'name': 'Oklahoma', 
         'abbreviation': 'OK'
    },
    {
         'name': 'Oregon', 
         'abbreviation': 'OR'
    },
    {
         'name': 'Pennsylvania', 
         'abbreviation': 'PA'
    },
    {
         'name': 'Puerto Rico', 
         'abbreviation': 'PR'
    },
    {
         'name': 'Rhode Island', 
         'abbreviation': 'RI'
    },
    {
    	'name': 'South Carolina', 
    	'abbreviation': 'SC'
    },
    {
         'name': 'South Dakota', 
         'abbreviation': 'SD'
    },
    {
         'name': 'Tennessee', 
         'abbreviation': 'TN'
    },
    {
         'name': 'Texas', 
         'abbreviation': 'TX'
    },
    {
         'name': 'Utah', 
         'abbreviation': 'UT'
    },
    {
         'name': 'Vermont', 
         'abbreviation': 'VT'
    },
    {
         'name': 'Virgin Islands', 
         'abbreviation': 'VI'
    },
    {
         'name': 'Virginia', 
         'abbreviation': 'VA'
    },
    {
         'name': 'Washington', 
         'abbreviation': 'WA'
    },
    {
         'name': 'West Virginia', 
         'abbreviation': 'WV'
    },
    {
         'name': 'Wisconsin', 
         'abbreviation': 'WI'
    },
    {
         'name': 'Wyoming', 
         'abbreviation': 'WY'
    }
]

states['ru'] = [

    {
    	'name': u'Амурская область',
    	'abbreviation': u'Амрск. обл.'
    },

    {
    	'name': u'Архангельская область',
    	'abbreviation': u'Арх-ая обл.'
    },

    {
    	'name': u'Астраханская область',
    	'abbreviation': u'Атр-ая обл.'
    },

    {
    	'name': u'Белгородская область',
    	'abbreviation': u'Белг. обл.'
    },

    {
    	'name': u'Брянская область',
    	'abbreviation': u'Брян. обл.'
    },

    {
    	'name': u'Челябинская область',
    	'abbreviation': u'Челяб. обл'
    },

    {
    	'name': u'Иркутская область',
    	'abbreviation': u'Ирк. обл'
    },

    {
    	'name': u'Ивановская область',
    	'abbreviation': u'Иван. обл.'
    },

    {
    	'name': u'Калининградская область',
    	'abbreviation': u'Калин. обл.'
    },

    {
    	'name': u'Калужская область',
    	'abbreviation': u'Калуж. обл.'
    },

    {
    	'name': u'Кемеровская область',
    	'abbreviation': u'Кем. обл.'
    },

    {
    	'name': u'Кировская область',
    	'abbreviation': u'Кир. обл.'
    },

    {
    	'name': u'Костромская область',
    	'abbreviation': u'Кос. обл.'
    },

    {
    	'name': u'Курганская область',
    	'abbreviation': u'Кург. обл.'
    },

    {
    	'name': u'Курская область' ,
    	'abbreviation': u'Курск. обл.'
    },

    {
    	'name': u'Ленинградская область',
    	'abbreviation': u'Лен. обл.'
    },

    {
    	'name': u'Липецкая область',
    	'abbreviation': u'Лип. обл.'
    },

    {
    	'name': u'Магаданская область',
    	'abbreviation': u'Маг. обл.'
    },

    {
    	'name': u'Московская область',
    	'abbreviation': u'Моск. обл.'
    },

    {
    	'name': u'Мурманская область',
    	'abbreviation': u'Мурм. обл.'
    },

    {
    	'name': u'Нижегородская область',
    	'abbreviation': u'Нижег. обл.'
    },

    {
    	'name': u'Новгородская область',
    	'abbreviation': u'Новг. обл.'
    },

    {
    	'name': u'Новосибирская область',
    	'abbreviation': u'Н-сиб. обл.'
    },

    {
    	'name': u'Омская область',
    	'abbreviation': u'Омск. обл.'
    },

    {
    	'name': u'Оренбургская область',
    	'abbreviation': u'Орен. обл.'
    },

    {
    	'name': u'Орловская область',
    	'abbreviation': u'Орл. обл.'
    },

    {
    	'name': u'Пензенская область',
    	'abbreviation': u'Пенз. обл.'
    },

    {
    	'name': u'Псковская область',
    	'abbreviation': u'Пск. обл.'
    },

    {
    	'name': u'Ростовская область',
    	'abbreviation': u'Рост. обл.'
    },

    {
    	'name': u'Рязанская область',
    	'abbreviation': u'Ряз. обл.'
    },

    {
    	'name': u'Сахалинская область',
    	'abbreviation': u'Сах. обл.'
    },

    {
    	'name': u'Самарская область',
    	'abbreviation': u'Сам. обл.'
    },

    {
    	'name': u'Саратовская область',
    	'abbreviation': u'Сар. обл.'
    },

    {
    	'name': u'Смоленская область',
    	'abbreviation': u'Смол. обл.'
    },

    {
    	'name': u'Свердловская область',
    	'abbreviation': u'Сверд. обл.'
    },

    {
    	'name': u'Тамбовская область',
    	'abbreviation': u'Тамб. обл.'
    },

    {
    	'name': u'Томская область',
    	'abbreviation': u'Том. обл.'
    },

    {
    	'name': u'Тверская область',
    	'abbreviation': u'Твер. обл.'
    },

    {
    	'name': u'Тульская область',
    	'abbreviation': u'Тул. обл.'
    },

    {
    	'name': u'Тюменская область',
    	'abbreviation': u'Тюм. обл.'
    },

    {
    	'name': u'Ульяновская область',
    	'abbreviation': u'Ул-ая обл.'
    },

    {
    	'name': u'Владимирская область',
    	'abbreviation': u'Влад. обл.'
    },

    {
    	'name': u'Волгоградская область',
    	'abbreviation': u'Вол. обл.'
    },

    {
    	'name': u'Вологодская область',
    	'abbreviation': u'Волог. обл.'
    },

    {
    	'name': u'Воронежская область',
    	'abbreviation': u'Ворон. обл.'
    },

    {
    	'name': u'Ярославская область',
    	'abbreviation': u'Ярос. обл.'
    },

    {
    	'name': u'Республика Адыгея ',
    	'abbreviation': u'р. Адыгея '
    },

    {
    	'name': u'Республика Алтай',
    	'abbreviation': u'р. Алтай'
    },

    {
    	'name': u'Республика Башкортостан ',
    	'abbreviation': u'р. Башкортостан '
    },

    {
    	'name': u'Республика Бурятия',
    	'abbreviation': u'р. Бурятия'
    },

    {
    	'name': u'Республика Дагестан ',
    	'abbreviation': u'р. Дагестан '
    },

    {
    	'name': u'Республика Ингушетия ',
    	'abbreviation': u'р. Ингушетия '
    },

    {
    	'name': u'Кабардино-Балкарская Республика',
    	'abbreviation': u'Кабардино-Балкарская р.'
    },

    {
    	'name': u'Республика Калмыкия',
    	'abbreviation': u'р. Калмыкия'
    },

    {
    	'name': u'Карачаево-Черкесская Республика',
    	'abbreviation': u'Кар.-Чер. -р.'
    },

    {
    	'name': u'Республика Карелия',
    	'abbreviation': u'р. Карелия'
    },

    {
    	'name': u'Республика Коми',
    	'abbreviation': u'р. Коми'
    },

    {
    	'name': u'Республика Марий Эл',
    	'abbreviation': u'р. Мар. Эл'
    },

    {
    	'name': u'Республика Мордовия',
    	'abbreviation': u'р. Мордовия'
    },

    {
    	'name': u'Республика Саха',
    	'abbreviation': u'р. Саха'
    },

    {
    	'name': u'Республика Северная',
    	'abbreviation': u'р. Северная'
    },

    {
    	'name': u'Республика Татарстан',
    	'abbreviation': u'р. Татарстан'
    },

    {
    	'name': u'Республика Тыва',
    	'abbreviation': u'р. Тыва'
    },

    {
    	'name': u'Удмуртская Республика',
    	'abbreviation': u'Удмуртская р.'
    },

    {
    	'name': u'Республика Хакасия',
    	'abbreviation': u'р. Хакасия'
    },

    {
    	'name': u'Чеченская Республика',
    	'abbreviation': u'Чеченская р.'
    },

    {
    	'name': u'Чувашская Республика',
    	'abbreviation': u'Чувашская р.'
    },

    {
    	'name': u'Республика Крым',
    	'abbreviation': u'р. Крым'
    },

    {
    	'name': u'Алтайский край',
    	'abbreviation': u'Алтайский край'
    },

    {
    	'name': u'Камчатский край',
    	'abbreviation': u'Камчатский кр.'
    },

    {
    	'name': u'Хабаровский край',
    	'abbreviation': u'Хабаровский кр.'
    },

    {
    	'name': u'Краснодарский край',
    	'abbreviation': u'Краснодарский кр.'
    },

    {
    	'name': u'Красноярский край',
    	'abbreviation': u'Красноярский кр.'
    },

    {
    	'name': u'Пермский край',
    	'abbreviation': u'Пермский кр.'
    },

    {
    	'name': u'Приморский кр.',
    	'abbreviation': u'Приморский кр.'
    },

    {
    	'name': u'Ставропольский кр.',
    	'abbreviation': u'Ставропольский кр.'
    },

    {
    	'name': u'Забайкальский кр.',
    	'abbreviation': u'Забайкальский кр.'
    }
]


import unittest
import chance
import chance_exceptions
import datetime
import re
import dictionaries


class TestChanceBooleanFunction(unittest.TestCase):

    def test_boolean_returns_bool(self):
        for x in xrange(0, 200):
            self.assertTrue(isinstance(chance.boolean(), (bool)))

    def test_likelihood_50_approximately_result(self):
        true_values, false_values = 0, 0
        iterations = 1000000
        likelihood = 0.5
        infelicity = 0.1

        for x in xrange(0, iterations):
            if chance.boolean(likelihood*100):
                true_values += 1
            else:
                false_values += 1
        res = float(true_values) / false_values
        
        self.assertTrue(res > (likelihood - infelicity))

    def test_likelihood_80_approximately_result(self):
        true_values, false_values = 0, 0
        iterations = 10000
        likelihood = 0.8
        infelicity = 0.1

        for x in xrange(0, iterations):
            if chance.boolean(likelihood*100):
                true_values += 1
            else:
                false_values += 1
        res = float(true_values) / false_values
        
        self.assertTrue(res > (likelihood - infelicity))


    def test_likelihood_10_approximately_result(self):
        true_values, false_values = 0, 0
        iterations = 10000
        likelihood = 0.1
        infelicity = 0.1

        for x in xrange(0, iterations):
            if chance.boolean(likelihood*100):
                true_values += 1
            else:
                false_values += 1
        res = float(true_values) / false_values
        
        self.assertTrue(res > (likelihood - infelicity))

    def test_boolean_raise_wrong_argument_exception(self):
        wrongs = (-1, -.1, 101, 101.1, 'a', 'b', '!')
        for x in wrongs:
            self.assertRaises(chance_exceptions.WrongArgumentValue, chance.boolean, x )


class TestChanceCharacterFunction(unittest.TestCase):
    
    def test_character_returns_character(self):
        chars = 'abcdefghijklmnopqrstuvwxyz!@#$%^&*()[]'
        chars += chars.upper()
        for x in xrange(100):
            ch = chance.character()
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_character_default_params(self):
        chars = 'abcdefghijklmnopqrstuvwxyz!@#$%^&*()[]'
        chars += chars.upper()
        for x in xrange(100):
            ch = chance.character()
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_character_default_symbols_false(self):
        chars = 'abcdefghijklmnopqrstuvwxyz!@#$%^&*()[]'
        chars += chars.upper()
        for x in xrange(100):
            ch = chance.character(symbols=False)
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_default_numbers_true(self):
        chars = 'abcdefghijklmnopqrstuvwxyz!@#$%^&*()[]'
        chars += chars.upper()
        chars += '1234567890'
        for x in xrange(100):
            ch = chance.character(symbols=False)
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_only_symbols(self):
        chars = '!@#$%^&*()[]'
        for x in xrange(100):
            ch = chance.character(symbols=True, alpha=False)
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_character_only_symbols_and_numbers(self):
        chars = '!@#$%^&*()[]'
        chars += '1234567890'
        for x in xrange(100):
            ch = chance.character(symbols=True, alpha=False, numbers=True)
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_only_alpha_and_numbers(self):
        chars = 'abcdefghijklmnopqrstuvwxyz'
        chars += chars.upper()
        chars += '1234567890'
        for x in xrange(100):
            ch = chance.character(symbols=False, alpha=True, numbers=True)
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_only_uppercase_alpha(self):
        chars = 'abcdefghijklmnopqrstuvwxyz'.upper()
        for x in xrange(100):
            ch = chance.character(case='upper', symbols=False,  numbers=False)
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_only_uppercase_alpha_and_symbols(self):
        chars = 'abcdefghijklmnopqrstuvwxyz'.upper()
        chars += '!@#$%^&*()[]'
        for x in xrange(100):
            ch = chance.character(case='upper', symbols=True,  numbers=False)
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_only_uppercase_alpha_and_numbers(self):
        chars = 'abcdefghijklmnopqrstuvwxyz'.upper()
        chars += '1234567890'
        for x in xrange(100):
            ch = chance.character(case='upper', symbols=False,  numbers=True)
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_only_uppercase_alpha_with_symbols_and_numbers(self):
        chars = 'abcdefghijklmnopqrstuvwxyz'.upper()
        chars += '!@#$%^&*()[]'
        chars += '1234567890'
        for x in xrange(100):
            ch = chance.character(case='upper', symbols=True,  numbers=True)
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_only_lower_alpha_with_symbols_and_numbers(self):
        chars = 'abcdefghijklmnopqrstuvwxyz'
        chars += '!@#$%^&*()[]'
        chars += '1234567890'
        for x in xrange(100):
            ch = chance.character(case='lower', symbols=True,  numbers=True)
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_only_lowecase_alpha(self):
        chars = 'abcdefghijklmnopqrstuvwxyz'
        for x in xrange(100):
            ch = chance.character(case='lower', symbols=False,  numbers=False)
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_only_lowercase_alpha_and_symbols(self):
        chars = 'abcdefghijklmnopqrstuvwxyz'
        chars += '!@#$%^&*()[]'
        for x in xrange(100):
            ch = chance.character(case='lower', symbols=True,  numbers=False)
            self.assertTrue(chars.find(ch) >= 0)

    def test_character_returns_only_lowercase_alpha_and_numbers(self):
        chars = 'abcdefghijklmnopqrstuvwxyz'
        chars += '1234567890'
        for x in xrange(100):
            ch = chance.character(case='lower', symbols=False,  numbers=True)
            self.assertTrue(chars.find(ch) >= 0)


    def test_character_raise_exception(self):
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.character, 10)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.character, -1)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.character, -.25)
        self.assertRaises(chance_exceptions.DictionaryException, chance.character,  **{'language':'bbdasasdg'})
        self.assertRaises(chance_exceptions.DictionaryException, chance.character,  **{'language':'ff'})


class TestStringFunction(unittest.TestCase):
    
    def test_string_returns_string(self):
        for x in range(100):
            self.assertTrue(isinstance(chance.string(), (str)))

    def test_string_returns_string_with_correct_length(self):
        for x in xrange(1, 100):
            self.assertTrue(len(chance.string(length=x))==x)
       
    def test_string_returns_string_with_correct_min_max(self):
        for x in xrange(1, 100):
            l = len(chance.string(minimum=x, maximum=x+5))
            self.assertTrue(l >= x and l <= (x+5))
        
    def test_string_returns_string_from_correct_pool(self):
        pools = (
            'abcdef',
            'hjfj2131',
            '$553\&66hjfj2131',
            '=_-232fdsf',
        )
        for pool in pools:
            s = chance.string(pool=pool)
            for x in s:
                self.assertTrue(pool.find(x) != -1)

    def test_string_raises_exception(self):
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.string, -1)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.string, -.1)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.string, 0)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.string, 1)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.string, .1)
        self.assertRaises(chance_exceptions.DictionaryException, chance.string, **{'language':'dfsdf'})
    

class TestSyllableFunction(unittest.TestCase):
    def test_syllable_returns_correct_string(self):
        syll = chance.syllable()
        for x in xrange(20):
            syll = chance.syllable(x+1)
            n = syll[0]
            nxt = dictionaries.vowels['en'] if dictionaries.consonants['en'].find(n) != -1 else dictionaries.vowels['en']
            prv = dictionaries.vowels['en'] if dictionaries.vowels['en'].find(n) != -1 else dictionaries.consonants['en'] 
            for i, ch in enumerate(syll):
                if i == 0 or i == (len(syll)-1):
                    continue
                self.assertFalse(nxt.find(ch) == -1)
                nxt, prv = prv, nxt

    def test_syllable_returns_correct_starting_string(self):
        
        for x in xrange(20):
            syll = chance.syllable(x+1, vowel_first=True)
            n = syll[0]
            self.assertFalse(dictionaries.vowels['en'].find(n) == -1)
            nxt = dictionaries.consonants['en']
            prv = dictionaries.vowels['en'] 
            for i, ch in enumerate(syll):
                if i == 0 or i == (len(syll)-1):
                    continue
                self.assertFalse(nxt.find(ch) == -1)
                nxt, prv = prv, nxt
        
        for x in xrange(20):
            syll = chance.syllable(x+1, vowel_first=False)
            n = syll[0]
            self.assertFalse(dictionaries.consonants['en'].find(n) == -1)
            nxt = dictionaries.vowels['en']
            prv = dictionaries.consonants['en']
            for i, ch in enumerate(syll):
                if i == 0 or i == (len(syll)-1):
                    continue
                self.assertFalse(nxt.find(ch) == -1)
                nxt, prv = prv, nxt

    def test_syllable_raises_exception(self):
           self.assertRaises(chance_exceptions.WrongArgumentValue, chance.syllable, 'a')
           self.assertRaises(chance_exceptions.WrongArgumentValue, chance.syllable, dict())
           self.assertRaises(chance_exceptions.WrongArgumentValue, chance.syllable, -1)
           self.assertRaises(chance_exceptions.WrongArgumentValue, chance.syllable, 1.5)
           self.assertRaises(chance_exceptions.DictionaryException, chance.syllable, **{'language':'dasdas'})


class TestWordFunction(unittest.TestCase):

    def test_word_returns_correct_value(self):
        for x in xrange(20):
            word = chance.word()
            self.assertEquals(str, type(word))
            self.assertTrue(len(word) > 3 and len(word) < 10)

    def test_word_raises_exception(self):
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.word, 'a')
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.word, dict())
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.word, -1)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.word, 1.5)
        self.assertRaises(chance_exceptions.DictionaryException, chance.word, **{'language':'dasdas'})

class TestSentenceFunction(unittest.TestCase):
    
    def test_sentence_returns_correct_value(self):
        for x in xrange(20):
            self.assertEquals(str, type(chance.sentence()))
            length = len(chance.sentence())
            self.assertTrue(length >= 45 and length <= 324)
        for x in xrange(50):
            self.assertEquals(str, type(chance.sentence(x+1)))
            
    def test_sentence_returns_correct_endings(self):
        end_pool = '?!.:'
        for x in end_pool:
            self.assertEquals(x, chance.sentence(ended_by=x)[-1:])
        last = chance.sentence(ended_by=end_pool)[-1:]
        self.assertTrue(end_pool.find(last) != -1)

    def test_sentence_raises_exception(self):
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.sentence, 'a')
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.sentence, dict())
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.sentence, -1)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.sentence, 1.5)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.sentence, 5, 12)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.sentence, 9, 18)
        self.assertRaises(chance_exceptions.DictionaryException, chance.sentence, **{'language':'dasdas'})


class TestParagraphFunction(unittest.TestCase):
    def test_pragraph_returns_correct_value(self):
        for x in xrange(20):
            self.assertEquals(str, type(chance.paragraph()))
            length = len(chance.paragraph())
            self.assertTrue(length >= 45)



class TestAgeFunction(unittest.TestCase):

    def test_age_returns_correct_value(self):
        for x in xrange(20):
            self.assertEquals(int, type(chance.age()))
            a = chance.age('child')
            self.assertTrue(a >= 1 and a <= 12 )
            a = chance.age('teen')
            self.assertTrue(a >= 13 and a <= 19 )
            a = chance.age('adult')
            self.assertTrue(a >= 18 and a <= 120 )
            a = chance.age('senior')
            self.assertTrue(a >= 65 and a <= 120 )
            a = chance.age()
            self.assertTrue(a >= 1 and a <= 120 )

    def test_age_raises_exception(self):
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.age, 'i\'m')



class TestDateFunction(unittest.TestCase):

    def test_date_returns_correct_value(self):
        for x in xrange(20):
            self.assertEquals(datetime.datetime, type(chance.date()))


class TestBirthdayFunction(unittest.TestCase):

    def test_birthday_returns_correct_value(self):
        current_year = datetime.date.today().year
        for x in xrange(20):
            self.assertEquals(datetime.date, type(chance.birthday()))
            self.assertTrue(datetime.date(current_year - 121, 1, 1) < chance.birthday())
            self.assertTrue(datetime.date(current_year - 13, 1, 1) < chance.birthday('child'))
            self.assertTrue(datetime.date(current_year - 20, 1, 1) < chance.birthday('teen'))
            self.assertTrue(datetime.date(current_year + 13, 1, 1) > chance.birthday('teen'))
            self.assertTrue(datetime.date(current_year + 20, 1, 1) > chance.birthday('teen'))

class TestFirstNameFunction(unittest.TestCase):

    def test_first_returns_correct_value(self):
        for x in xrange(20):
            self.assertEquals(str, type(chance.first()))


    def test_first_returns_only_gender_specified_name(self):
        from dictionaries import first_names
        names = first_names['en']
        for x in xrange(20):
            name = chance.first(gender='m')
            self.assertTrue(name in names['m'])
        for x in xrange(20):
            name = chance.first(gender='female')
            self.assertTrue(name in names['f'])

class TestLastNameFunction(unittest.TestCase):

    def test_first_returns_correct_value(self):
        for x in xrange(20):
            self.assertEquals(str, type(chance.last()))


    def test_first_returns_only_gender_specified_name(self):
        from dictionaries import last_names
        names = last_names['en']
        for x in xrange(20):
            name = chance.last(gender='m')
            self.assertTrue(name in names['m'])
        for x in xrange(20):
            name = chance.last(gender='female')
            self.assertTrue(name in names['f'])


class TestNameFunction(unittest.TestCase):

    def test_name_returns_correct_value(self):
        for x in xrange(20):
            self.assertEquals(str, type(chance.name()))


    def test_name_returns_only_gender_specified_name(self):
        from dictionaries import last_names, first_names
        first_names = first_names['en']
        last_names= last_names['en']
        for x in xrange(20):
            name = chance.name(gender='m')
            first, last = name.split(' ')
            self.assertTrue(first in first_names['m'])
            self.assertTrue(last in last_names['m'])
        for x in xrange(20):
            name = chance.name(gender='f')
            first, last = name.split(' ')
            self.assertTrue(first in first_names['f'])
            self.assertTrue(last in last_names['f'])

    def test_name_returns_only_language_specified_name(self):
        from dictionaries import last_names, first_names
        first_names = first_names['ru']
        last_names= last_names['ru']
        for x in xrange(200):
            name = chance.name(gender='m', language='ru')
            first, last = name.split(' ')
            self.assertTrue(first in first_names['m'])
            self.assertTrue(last in last_names['m'])
        for x in xrange(200):
            name = chance.name(gender='f', language='ru')
            first, last = name.split(' ')
            self.assertTrue(first in first_names['f'])
            self.assertTrue(last in last_names['f'])

class TestHashFunction(unittest.TestCase):
    
    def test_hash_returns_correct_value(self):
        for x in xrange(20):
            self.assertEquals(int, type(hash(chance.hex_hash())))

class TestColorFunction(unittest.TestCase):
    
    def test_color_returns_correct_value(self):
        hex_color_pattern = re.compile('^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$')
        rgb_color_pattern = re.compile('rgb\((\d{1,3}), (\d{1,3}), (\d{1,3})\)')
        
        for x in xrange(20):
            hex_color = chance.color(form='hex')
            rgb_color = chance.color(form='rgb')
            gray_color = chance.color(grayscale=True)
            self.assertTrue(hex_color_pattern.match(hex_color) != None)
            self.assertTrue(hex_color_pattern.match(gray_color) != None)

            matches = rgb_color_pattern.findall(rgb_color)
            self.assertTrue(len(matches)==1)
            self.assertTrue(len(matches[0])==3)
            for x in matches[0]:
                self.assertTrue(int(x) >= 0 and int(x) <= 255)
            
         
    def test_color_raises_exception(self):
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.color, 'i\'m')
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.color, 'sitting')
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.color, 'in')
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.color, 'my')
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.color, 'room')
   

class TestDomainFunction(unittest.TestCase):
    
    def test_domain_returns_correct_value(self):
        domain_pattern = re.compile('^([A-Za-z0-9]+\.[a-z\.]{2,5})$')
       
        for x in xrange(20):
            self.assertTrue(domain_pattern.match(chance.domain()) != None)
         
    def test_domain_raises_exception(self):
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.domain, 2)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.domain, 1)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.domain, -1)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.domain, .1)
   
class TestEmailFunction(unittest.TestCase):
    def test_email_returns_correct_values(self):
        email_pattern = re.compile('^([A-Za-z0-9]+@[A-Za-z0-9]+\.[a-z\.]{2,5})$')

        for x in xrange(20):
            self.assertTrue(email_pattern.match(chance.email()) != None)

    def test_email_raises_exception(self):
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.email, 2)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.email, 1)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.email, -1)
        self.assertRaises(chance_exceptions.WrongArgumentValue, chance.email, .1)

class TestIpFunction(unittest.TestCase):
    def test_ip_returns_correct_values(self):
        ip_pattern = re.compile('^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}$')
        for x in xrange(20):
            self.assertTrue(ip_pattern.match(chance.ip()) != None)


class TestStreetFunction(unittest.TestCase):
    def test_street_returns_string_type(self):
        for x in xrange(10):
            self.assertEquals(type(chance.street()), str)
    
    def test_street_returns_unicode(self):
        for x in xrange(10):
            self.assertEquals(type(chance.street(language='ru')), unicode)


class TestStateFunction(unittest.TestCase):
    def test_state_returns_string(self):
        for x in xrange(20):
            self.assertEquals(type(chance.state()), str)

    def test_short_state(self):
        for x in xrange(20):
            st = chance.state(short=True)
            self.assertTrue(len(st) > 1 and len(st) < 4)

    def test_state_returns_correct_language(self):
        all_states = [x['name'] for x in dictionaries.states['en']]
        for x in xrange(20):
            self.assertTrue(chance.state() in all_states)

    def test_state_short_returns_correct_language(self):
        all_states = [x['abbreviation'] for x in dictionaries.states['en']]
        for x in xrange(20):
            self.assertTrue(chance.state(short=True) in all_states)


class TestCityFuncton(unittest.TestCase):
    def test_city_returns_string(self):
        for x in xrange(20):
            self.assertEquals(type(chance.city()), str)


class TestPhoneFunction(unittest.TestCase):
    def test_phone_returns_string(self):
        for x in xrange(20):
           self.assertEquals(str, type(chance.phone()))    

class TestDictionaryFunction(unittest.TestCase):
    def test_dictionary_returns_dict(self):
        example = {
            'first_name': ('first', dict(language='ru')),
            'last_name': ('last', dict(language='ru')),
            'phone': ('phone', dict()),
            'email': ('email', dict()),
            'birthday': ('birthday', dict()),
            'password': '123'
        }
        for x in xrange(10):
            d = chance.dictionary(example)
            for key in example:
                self.assertTrue(key in d)


class TestUnixPathFunction(unittest.TestCase):
    
    def test_correct_value(self):
        path = chance.path()
        for x in xrange(4):
            self.assertTrue(isinstance(path, str))

        for x in xrange(4):
            self.assertTrue(isinstance(path, str))
            self.assertEquals(len(chance.path(depth=3).split('/')), 4)
            self.assertEquals(len(chance.path(depth=4).split('/')), 5)
            self.assertEquals(len(chance.path(depth=6).split('/')), 7)

        for x in xrange(4):
            self.assertTrue(len(chance.path().split('/')) >= 5 and len(chance.path().split('/')) <= 7)
           

class TestUnixFilePathFunction(unittest.TestCase):
    
    def test_correct_value_type(self):
        path = chance.filepath()
        for x in xrange(4):
            self.assertTrue(isinstance(path, str))

    def test_unix_filepath_kind(self):
        for x in xrange(20):
            fpath = chance.filepath()
            pieces = fpath.split('/')
            self.assertTrue(len(pieces) >= 6 and len(pieces) <= 8, (len(pieces), pieces,))
            self.assertTrue(pieces[-1:][0].find('.') > 0)
            
    def test_unix_filepath_returns_correct_extention(self):
        exts = ['hhj']
        for x in xrange(20):
            fpath = chance.filepath(extentions=exts)
            pieces = fpath.split('/')
            self.assertTrue(len(pieces) >= 6 and len(pieces) <= 8, (len(pieces), pieces,))
            self.assertTrue(pieces[-1:][0].find('.') > 0)
            ext = pieces[-1:][0].split('.')[1]
            self.assertTrue( any(ext == x for x in exts))
        
        exts = ['txt', 'emuy']
        for x in xrange(20):
            fpath = chance.filepath(extentions=exts)
            pieces = fpath.split('/')
            self.assertTrue(len(pieces) >= 6 and len(pieces) <= 8, (len(pieces), pieces,))
            self.assertTrue(pieces[-1:][0].find('.') > 0)
            ext = pieces[-1:][0].split('.')[1]
            self.assertTrue( any(ext == x for x in exts))

        exts = ['txt', 'emuy', 'core']
        for x in xrange(20):
            fpath = chance.filepath(extentions=exts)
            pieces = fpath.split('/')
            self.assertTrue(len(pieces) >= 6 and len(pieces) <= 8, (len(pieces), pieces,))
            self.assertTrue(pieces[-1:][0].find('.') > 0)
            ext = pieces[-1:][0].split('.')[1]
            self.assertTrue( any(ext == x for x in exts))


            

if __name__ == '__main__':
    unittest.main()




class DictionaryException(Exception):
    """
    Exception raised when dictionary from dictionraies.py not found.
    """

class WrongArgumentValue(Exception):
    def init(self, message, errors):
        Exception.__init__(self, message)
        self.errors = errors


from distutils.core import setup
setup(
    name='chance',
    packages=['chance'],
    version='0.101',
    description='Minimalist generator of random strings, numbers, etc.',
    author='Davit Vardanyan',
    author_email='davoimail@gmail.com',
    url='https://github.com/davitv/chance',
    download_url='http://github.com/davitv/chance/tarball/0.1',
    keywords=['random', 'generator', 'chancejs'],
    classifiers=[],
)
